import os
import sys
import tempfile
from zipfile import ZipFile

from django.test import TestCase
from model_bakery import baker

from celeryui.models import Report

from bpp.models import (
    Charakter_Formalny,
    Redakcja_Zrodla,
    Rekord,
    Typ_KBN,
    Tytul,
    Zasieg_Zrodla,
    Zrodlo,
)
from bpp.models.autor import Autor
from bpp.models.praca_habilitacyjna import Publikacja_Habilitacyjna
from bpp.models.system import Jezyk
from bpp.reports.komisja_centralna import (
    Raport_Dla_Komisji_Centralnej,
    RaportKomisjiCentralnej,
    RokHabilitacjiNiePodany,
    get_queries,
    make_report_zipfile,
)
from bpp.tests.tests_legacy.test_reports.util import stworz_obiekty_dla_raportow
from bpp.tests.util import (
    CURRENT_YEAR,
    any_autor,
    any_ciagle,
    any_habilitacja,
    any_jednostka,
    any_patent,
    any_zwarte,
)
from bpp.util import Getter


class TestRKCMixin:
    def odpal_browser(self, res):
        handle, fn = tempfile.mkstemp(".html")
        os.write(handle, res.encode("utf-8"))
        os.close(handle)

        if sys.platform == "win32":
            os.system("start %s" % fn)
        if sys.platform == "darwin":
            os.system('open "%s"' % fn)


class TestRaportKomisjiCentralnej(TestRKCMixin, TestCase):
    def setUp(self):
        stworz_obiekty_dla_raportow()

        typ_kbn = Getter(Typ_KBN)
        charakter = Getter(Charakter_Formalny)
        zasieg = Getter(Zasieg_Zrodla, "nazwa")
        tytul = Getter(Tytul)  # noqa
        jezyk = Getter(Jezyk)

        self.jednostka = any_jednostka()

        self.autor = any_autor()

        self.prace = {}

        self.krajowe_zrodlo = baker.make(Zrodlo, zasieg=zasieg.krajowy)
        Redakcja_Zrodla.objects.create(
            zrodlo=self.krajowe_zrodlo, redaktor=self.autor, od_roku=CURRENT_YEAR
        )

        self.miedzynarodowe_zrodlo = baker.make(Zrodlo, zasieg=zasieg["międzynarodowy"])
        Redakcja_Zrodla.objects.create(
            zrodlo=self.miedzynarodowe_zrodlo, redaktor=self.autor, od_roku=CURRENT_YEAR
        )

        def dwie(idx, tytul_oryginalny, **kw):
            self.prace[idx] = any_ciagle(tytul_oryginalny=tytul_oryginalny, **kw)

            self.prace[idx + "-2"] = any_ciagle(
                tytul_oryginalny=tytul_oryginalny + "-2", **kw
            )

        args_1a = dict(
            typ_kbn=typ_kbn.PO,
            charakter_formalny=charakter.AC,
            impact_factor=10,
            punkty_kbn=5,
        )
        dwie("1a", "Praca-1", **args_1a)

        args_1b = dict(
            typ_kbn=typ_kbn.PO,
            charakter_formalny=charakter.AC,
            impact_factor=0,
            punkty_kbn=5,
        )
        dwie("1b", "Praca-2", **args_1b)

        args_2a = dict(
            impact_factor=5,
            typ_kbn=typ_kbn.CR,
            charakter_formalny=charakter.AC,
            punkty_kbn=5,
        )
        dwie("2a", "Praca-3", **args_2a)

        args_2b = dict(
            impact_factor=0,
            typ_kbn=typ_kbn.CR,
            charakter_formalny=charakter.AC,
            punkty_kbn=5,
        )
        dwie("2b", "Praca-4", **args_2b)

        args_3a = dict(
            impact_factor=5,
            typ_kbn=typ_kbn.PP,
            punkty_kbn=5,
            charakter_formalny=charakter.AC,
        )
        dwie("3a", "Praca-5", **args_3a)

        args_3b = dict(
            impact_factor=0,
            typ_kbn=typ_kbn.PP,
            charakter_formalny=charakter.AC,
            punkty_kbn=5,
        )
        dwie("3b", "Praca-6", **args_3b)

        # args_4
        dwie(
            "4c1", "Praca-6.5", charakter_formalny=charakter["KSZ"], jezyk=jezyk["ang."]
        )
        dwie(
            "4c2",
            "Praca-6.75",
            charakter_formalny=charakter["KSP"],
            jezyk=jezyk["pol."],
        )

        # args_5
        dwie("5", "Praca-7", typ_kbn=typ_kbn["000"], charakter_formalny=charakter.AC)
        dwie("5a", "Praca-7a", typ_kbn=typ_kbn["PNP"])
        any_habilitacja(tytul_oryginalny="NIE WEJDZIE")
        any_habilitacja(tytul_oryginalny="NIE WEJDZIE")
        any_habilitacja(tytul_oryginalny="NIE WEJDZIE")

        p = any_patent()
        h = any_habilitacja(tytul_oryginalny="WEJDZIE")
        Publikacja_Habilitacyjna.objects.create(praca_habilitacyjna=h, publikacja=p)

        # 7a
        args_7a = dict(jezyk=jezyk["ang."], charakter_formalny=charakter.KSZ)
        any_zwarte(tytul_oryginalny="PRACA 7a", **args_7a).dodaj_autora(
            self.autor, self.jednostka, typ_odpowiedzialnosci_skrot="red."
        )

        # Praca 7a nie wejdzie do punktu 7a, ale do 4c1 już tak :-)
        any_zwarte(tytul_oryginalny="PRACA 7a NIE MA", **args_7a).dodaj_autora(
            self.autor, self.jednostka, typ_odpowiedzialnosci_skrot="aut."
        )
        # 7b
        any_zwarte(
            tytul_oryginalny="PRACA 7b1",
            jezyk=jezyk["pol."],
            charakter_formalny=charakter.KSZ,
        ).dodaj_autora(self.autor, self.jednostka, typ_odpowiedzialnosci_skrot="red.")

        any_zwarte(
            tytul_oryginalny="PRACA 7b2",
            jezyk=jezyk["pol."],
            charakter_formalny=charakter.KSP,
        ).dodaj_autora(self.autor, self.jednostka, typ_odpowiedzialnosci_skrot="red.")

        # dodam autora o typie redaktor
        # stworze prace o takich samych argumentach ale bez redaktora

        args_8a = dict(charakter_formalny=charakter.ZSZ)
        dwie("8a", "Praca-8", **args_8a)

        args_8b = dict(charakter_formalny=charakter.PSZ)
        dwie("8b", "Praca-9", **args_8b)

        self.prace["9a"] = any_ciagle(
            charakter_formalny=charakter.Supl,
            impact_factor=0,
            punkty_kbn=111,
            kc_impact_factor=222,
            kc_punkty_kbn=None,
            tytul_oryginalny="Praca-10 ma mieć IMPACT 222 i KBN 111",
        )

        self.prace["9a-1"] = any_ciagle(
            charakter_formalny=charakter.Supl,
            impact_factor=5,
            punkty_kbn=111,
            kc_impact_factor=222,
            kc_punkty_kbn=444,
            tytul_oryginalny="Praca-10 ma mieć IMPACT 222 i KBN 444",
        )

        #
        self.prace["9b"] = any_ciagle(
            charakter_formalny=charakter.Supl,
            impact_factor=0,
            punkty_kbn=0,
            kc_impact_factor=None,
            kc_punkty_kbn=333,
            tytul_oryginalny="Praca-11 ma mieć KBN 333 i ZERO impactu",
        )

        self.prace["9b-1"] = any_ciagle(
            charakter_formalny=charakter.Supl,
            impact_factor=0,
            punkty_kbn=1,
            kc_impact_factor=None,
            kc_punkty_kbn=555,
            tytul_oryginalny="Praca-11 ma mieć KBN 555 i ZERO impactu",
        )

        args_10a = dict(charakter_formalny=charakter.L, impact_factor=5, punkty_kbn=5)
        dwie("10a", "Praca-12", **args_10a)

        args_10b = dict(charakter_formalny=charakter.L, impact_factor=0, punkty_kbn=5)
        dwie("10b", "Praca-13", **args_10b)

        args_11a = dict(typ_kbn=typ_kbn.PW, impact_factor=5, punkty_kbn=5)
        dwie("11a", "Praca-14", **args_11a)

        args_11b = dict(typ_kbn=typ_kbn.PW, impact_factor=0, punkty_kbn=5)
        dwie("11b", "Praca-15", **args_11b)

        self.prace["IIIpat"] = any_patent(tytul_oryginalny="Praca-16")

        for praca in list(self.prace.values()):
            praca.dodaj_autora(self.autor, self.jednostka)

        Rekord.objects.full_refresh()

        self._zrob()

    def _zrob(self):
        self.raport = RaportKomisjiCentralnej(self.autor)
        self.s = self.raport.make_prace()
        return self.s

    def _test_tabelka(self, key):
        # s = self._zrob()
        # self.odpal_browser(s)
        self.assertIn(self.prace[key].tytul_oryginalny, self.s)

    def test_1a(self):
        return self._test_tabelka("1a")

    def test_1b(self):
        return self._test_tabelka("1b")

    def test_2a(self):
        return self._test_tabelka("2a")

    def test_2b(self):
        return self._test_tabelka("2b")

    def test_3a(self):
        return self._test_tabelka("3a")

    def test_3b(self):
        return self._test_tabelka("3b")

    def test_4c(self):
        haystack = self._zrob().replace("\r\n", "").replace("\t", "")
        for a in range(10):
            haystack = haystack.replace("  ", " ")

        needles = [
            "C. Autorstwo monografii lub podręcznika:\n </td><td>liczba: 5",
            "C1. w języku angielskim\n </td><td>liczba: 3",
            "C2. w języku polskim lub innym niż angielski\n </td><td>liczba: 2",
        ]
        self.assertIn(needles[0], haystack)
        self.assertIn(needles[1], haystack)
        self.assertIn(needles[2], haystack)

    def test_5(self):
        s = self._zrob()
        self.assertIn("naukowe i inne, liczba prac: 5", s)

    def test_6(self):
        s = self._zrob()
        self.assertIn("A. międzynarodowym</td><td>liczba: 1", s)
        self.assertIn("B. krajowym</td><td>liczba: 1", s)

    def test_7(self):
        s = self._zrob()
        self.assertIn("A. w języku angielskim</td><td>liczba: 1", s)
        self.assertIn(
            "B. w języku polskim lub innym, niż angielski</td><td>liczba: 2", s
        )

    def test_8(self):
        s = self._zrob()
        self.assertIn("Liczba streszczeń: 4", s)
        self.assertIn("A. ze zjazd\xf3w mi\u0119dzynarodowych</td><td>liczba: 2", s)
        self.assertIn("B. ze zjazd\xf3w krajowych</td><td>liczba: 2", s)

    def test_9(self):
        for a in ["111", "222", "333", "444", "555", "888"]:  # <-- to są sumy
            self.assertIn(a, self._zrob())

    def test_10a(self):
        self._test_tabelka("10a")

    def test_10b(self):
        self._test_tabelka("10b")

    def test_10_suma(self):
        s = self._zrob()
        self.assertIn("X. Liczba listów do redakcji czasopism: 4", s)

    def test_11a(self):
        return self._test_tabelka("11a")

    def test_11b(self):
        return self._test_tabelka("11b")

    def test_11_suma(self):
        s = self._zrob()
        self.assertIn("XI. Liczba publikacji z udzia", s)
        self.assertIn("wieloośrodkowych: 4", s)

    def test_punktacja_sumaryczna(self):
        self.s = self._zrob()
        dct = self.raport.policz_sumy()

        def sprawdz_sumy(no, oczekiwany_count, oczekiwany_if, oczekiwany_pk):
            key = "suma_%s" % no

            self.assertEqual(dct.get(key)["count"], oczekiwany_count, msg=key)
            self.assertEqual(dct.get(key)["impact_factor"], oczekiwany_if, msg=key)
            self.assertEqual(dct.get(key)["punkty_kbn"], oczekiwany_pk, msg=key)

        sprawdz_sumy(1, 4, 20, 20)
        sprawdz_sumy(2, 4, 10, 20)
        sprawdz_sumy(3, 4, 10, 20)
        sprawdz_sumy(9, 4, 444, 1443)
        sprawdz_sumy(10, 4, 10, 20)
        sprawdz_sumy(11, 4, 10, 20)
        self.assertEqual(dct["suma_5"]["count"], 5)
        self.assertEqual(dct["suma_8"]["count"], 4)

    def test_punktacja_sumaryczna_render(self):
        res = self.raport.punktacja_sumaryczna()
        self.assertIn("doktora habilitowanego", res)
        # self.odpal_browser(res)


class TestRaportKomisjiCentralnejPrzedPoHabilitacji(TestRKCMixin, TestCase):
    def setUp(self):
        stworz_obiekty_dla_raportow()

        typ_kbn = Getter(Typ_KBN)
        charakter = Getter(Charakter_Formalny)
        zasieg = Getter(Zasieg_Zrodla, "nazwa")  # noqa
        tytul = Getter(Tytul)  # noqa
        jezyk = Getter(Jezyk)  # noqa

        self.jednostka = any_jednostka()
        self.habilitowany = any_autor()

        args_1a = dict(
            typ_kbn=typ_kbn.PO,
            charakter_formalny=charakter.AC,
            impact_factor=10,
            punkty_kbn=5,
        )

        self.praca_przed = any_ciagle(
            tytul_oryginalny="Praca-PRZED", rok=CURRENT_YEAR, **args_1a
        )
        self.praca_przed.dodaj_autora(self.habilitowany, self.jednostka)

        self.praca_po = any_ciagle(
            tytul_oryginalny="Praca-PO", rok=CURRENT_YEAR + 1, **args_1a
        )
        self.praca_po.dodaj_autora(self.habilitowany, self.jednostka)

        Rekord.objects.full_refresh()

        self.raport_przed = RaportKomisjiCentralnej(
            self.habilitowany, przed_habilitacja=True, rok_habilitacji=CURRENT_YEAR
        )

        self.raport_po = RaportKomisjiCentralnej(
            self.habilitowany, przed_habilitacja=False, rok_habilitacji=CURRENT_YEAR
        )

    def test_raport_przed(self):
        s = self.raport_przed.make_prace()
        res = self.raport_przed.dct
        self.assertEqual(res["tabela_1a"].counter, 1)
        self.assertEqual(res["tabela_1a"].columns["impact_factor"].footer, 10)
        self.assertIn("Praca-PRZED", s)
        self.assertIn("Dorobek przedhabilitacyjny", s)
        self.assertIn("profesora", s)

    def test_raport_po(self):
        s = self.raport_po.make_prace()
        res = self.raport_po.dct
        self.assertEqual(res["tabela_1a"].counter, 1)
        self.assertEqual(res["tabela_1a"].columns["impact_factor"].footer, 10)
        self.assertIn("Praca-PO", s)
        self.assertIn("Dorobek pohabilitacyjny", s)
        self.assertIn("profesora", s)

    def test_po_raises(self):
        self.assertRaises(
            RokHabilitacjiNiePodany,
            get_queries,
            self.habilitowany,
            przed_habilitacja=False,
            rok_habilitacji=None,
        )


class TestRaportKomisjiCentralnejZipfile(TestRKCMixin, TestCase):
    def setUp(self):
        stworz_obiekty_dla_raportow()

        typ_kbn = Getter(Typ_KBN)
        charakter = Getter(Charakter_Formalny)
        zasieg = Getter(Zasieg_Zrodla, "nazwa")  # noqa
        tytul = Getter(Tytul)
        jezyk = Getter(Jezyk)  # noqa

        self.jednostka = any_jednostka()
        # Takie nazwisko, bo używamy potem autor.slug do wygnerowania nazwy pliku
        self.habilitowany = any_autor(
            nazwisko="Łącki 'al' \"Habib\" ", imiona="Jąń??\\/", tytul=tytul["dr"]
        )

        # Odbuduj sluga
        self.habilitowany.slug = None
        self.habilitowany.save()

        args_1a = dict(
            typ_kbn=typ_kbn.PO,
            charakter_formalny=charakter.AC,
            impact_factor=10,
            punkty_kbn=5,
        )

        self.praca_przed = any_ciagle(
            tytul_oryginalny="Praca-PRZED", rok=CURRENT_YEAR, **args_1a
        )
        self.praca_przed.dodaj_autora(self.habilitowany, self.jednostka)

        self.praca_po = any_ciagle(
            tytul_oryginalny="Praca-PO", rok=CURRENT_YEAR + 1, **args_1a
        )
        self.praca_po.dodaj_autora(self.habilitowany, self.jednostka)

    def test_make_zipfile(self):
        zn = make_report_zipfile(self.habilitowany.pk, CURRENT_YEAR)
        with ZipFile(zn, "r") as zip:
            self.assertEqual(len(zip.infolist()), 6)

    def test_make_zipfile_bez_habilitacji(self):
        zn = make_report_zipfile(self.habilitowany.pk, None)
        with ZipFile(zn, "r") as zip:
            self.assertEqual(len(zip.infolist()), 3)

    def test_raport_dla_komisji_centralnej(self):
        autor = baker.make(Autor)
        r = baker.make(Report, arguments={"rok_habilitacji": "2017", "autor": autor.pk})
        x = Raport_Dla_Komisji_Centralnej(r)
        x.perform()

        r.file.open()
        self.assertTrue(True)



# -*- coding: utf-8 -*-


from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0033_auto_20151001_1425'),
    ]

    operations = [
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_ilosc_miesiecy',
            field=models.PositiveIntegerField(help_text=b'Ilo\xc5\x9b\xc4\x87 miesi\xc4\x99cy jakie up\xc5\x82yn\xc4\x99\xc5\x82y od momentu opublikowania do momentu udost\xc4\x99pnienia', null=True, verbose_name=b'OpenAccess: ilo\xc5\x9b\xc4\x87 miesi\xc4\x99cy', blank=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_ilosc_miesiecy',
            field=models.PositiveIntegerField(help_text=b'Ilo\xc5\x9b\xc4\x87 miesi\xc4\x99cy jakie up\xc5\x82yn\xc4\x99\xc5\x82y od momentu opublikowania do momentu udost\xc4\x99pnienia', null=True, verbose_name=b'OpenAccess: ilo\xc5\x9b\xc4\x87 miesi\xc4\x99cy', blank=True),
            preserve_default=True,
        ),
    ]



# Generated by Django 2.2.10 on 2020-02-23 20:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0196_uczelnia_pokazuj_raport_slotow_zerowy"),
    ]

    operations = [
        migrations.AlterField(
            model_name="patent",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="podpowiadaj_dyscypliny",
            field=models.BooleanField(
                default=True,
                help_text='W sytuacji gdy to pole ma wartość "PRAWDA", system będzie podpowiadał dyscyplinę\n        naukową dla powiązania rekordu wydawnictwa i autora w sytuacji, gdy autor ma na dany rok\n        określoną tylko jedną dyscyplinę. W sytuacji przypisania dla autora dwóch dyscyplin na dany rok,\n        pożądaną dyscyplinę będzie trzeba wybrać ręcznie, niezależnie od ustawienia tego pola. ',
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ',
                max_length=250,
                null=True,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-06-23 23:30


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('bpp', '0076_auto_20170622_0058'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='publikacja_habilitacyjna',
            unique_together=set([('praca_habilitacyjna', 'content_type', 'object_id')]),
        ),
    ]



# Generated by Django 3.2.14 on 2022-07-10 20:13

import django.db.models.deletion
from django.db import migrations, models

import bpp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("bpp", "0325_nullbooleanfield"),
    ]

    operations = [
        migrations.CreateModel(
            name="Zgloszenie_Publikacji",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "tytul_oryginalny",
                    models.TextField(db_index=True, verbose_name="Tytuł oryginalny"),
                ),
                (
                    "tytul",
                    models.TextField(
                        blank=True, db_index=True, null=True, verbose_name="Tytuł"
                    ),
                ),
                (
                    "www",
                    models.URLField(
                        blank=True,
                        max_length=1024,
                        null=True,
                        verbose_name="Adres WWW (płatny dostęp)",
                    ),
                ),
                (
                    "dostep_dnia",
                    models.DateField(
                        blank=True,
                        help_text="Data dostępu do strony WWW.",
                        null=True,
                        verbose_name="Dostęp dnia (płatny dostęp)",
                    ),
                ),
                (
                    "public_www",
                    models.URLField(
                        blank=True,
                        max_length=2048,
                        null=True,
                        verbose_name="Adres WWW (wolny dostęp)",
                    ),
                ),
                (
                    "public_dostep_dnia",
                    models.DateField(
                        blank=True,
                        help_text="Data wolnego dostępu do strony WWW.",
                        null=True,
                        verbose_name="Dostęp dnia (wolny dostęp)",
                    ),
                ),
                (
                    "doi",
                    bpp.fields.DOIField(
                        blank=True,
                        db_index=True,
                        help_text="Digital Object Identifier (DOI)",
                        max_length=2048,
                        null=True,
                        verbose_name="DOI",
                    ),
                ),
                (
                    "opl_pub_cost_free",
                    models.BooleanField(
                        null=True, verbose_name="Publikacja bezkosztowa"
                    ),
                ),
                (
                    "opl_pub_research_potential",
                    models.BooleanField(
                        help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                        null=True,
                        verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
                    ),
                ),
                (
                    "opl_pub_research_or_development_projects",
                    models.BooleanField(
                        help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych "
                        "lub prac rozwojowych",
                        null=True,
                        verbose_name="Środki finansowe na realizację projektu",
                    ),
                ),
                (
                    "opl_pub_other",
                    models.BooleanField(
                        blank=True,
                        default=None,
                        null=True,
                        verbose_name="Inne środki finansowe",
                    ),
                ),
                (
                    "opl_pub_amount",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        max_digits=20,
                        null=True,
                        verbose_name="Kwota (zł)",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Zgloszenie_Publikacji_Autor",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("kolejnosc", models.IntegerField(default=0, verbose_name="Kolejność")),
                ("zapisany_jako", models.CharField(max_length=512)),
                (
                    "afiliuje",
                    models.BooleanField(
                        default=True,
                        help_text="Afiliuje\n    się do jednostki podanej w przypisaniu. Jednostka nie może być obcą. ",
                    ),
                ),
                (
                    "zatrudniony",
                    models.BooleanField(
                        default=False,
                        help_text="Pracownik\n    jednostki podanej w przypisaniu",
                    ),
                ),
                (
                    "procent",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        max_digits=5,
                        null=True,
                        verbose_name="Udział w opracowaniu (procent)",
                    ),
                ),
                (
                    "przypieta",
                    models.BooleanField(
                        db_index=True,
                        default=True,
                        help_text='Możesz odznaczyć, żeby "odpiąć" dyscyplinę od tego autora. Dyscyplina "odpięta" '
                        "nie będzie\n        wykazywana do PBN oraz nie będzie używana do liczenia punktów "
                        "dla danej pracy.",
                    ),
                ),
                (
                    "upowaznienie_pbn",
                    models.BooleanField(
                        default=False,
                        help_text='Tik w polu "upoważnienie PBN" oznacza, że dany autor upoważnił Uczelnię do '
                        "sprawozdania tej publikacji w ocenie parametrycznej Uczelni",
                        verbose_name="Upoważnienie PBN",
                    ),
                ),
                (
                    "profil_orcid",
                    models.BooleanField(
                        default=False,
                        help_text="Zaznacz, jeżeli praca znajdje się na profilu ORCID autora",
                        verbose_name="Praca w profilu ORCID autora",
                    ),
                ),
                (
                    "data_oswiadczenia",
                    models.DateField(
                        blank=True,
                        help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                        null=True,
                        verbose_name="Data oświadczenia",
                    ),
                ),
                (
                    "autor",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="bpp.autor"
                    ),
                ),
                (
                    "dyscyplina_naukowa",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="bpp.dyscyplina_naukowa",
                    ),
                ),
                (
                    "jednostka",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="bpp.jednostka"
                    ),
                ),
                (
                    "rekord",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="zglos_publikacje.zgloszenie_publikacji",
                    ),
                ),
                (
                    "typ_odpowiedzialnosci",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.typ_odpowiedzialnosci",
                        verbose_name="Typ odpowiedzialności",
                    ),
                ),
            ],
            options={
                "ordering": ("kolejnosc", "typ_odpowiedzialnosci__skrot"),
                "abstract": False,
            },
        ),
    ]



# Generated by Django 3.0.11 on 2020-12-25 18:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0227_auto_20201011_0010'),
        ('bpp', '0225_charakter_sloty_referat'),
    ]

    operations = [
    ]



"""Models for in-database representation of dynamic admin columns configuration.
"""
import re

from django.conf import settings
from django.db import models
from django.db.models import Max

from dynamic_columns.exceptions import CodeAccessNotAllowed
from dynamic_columns.util import qual, str_to_class

from django.contrib.admin import ModelAdmin as DjangoModelAdmin
from django.contrib.contenttypes.models import ContentType

from django.utils.datastructures import OrderedSet
from django.utils.functional import cached_property
from django.utils.translation import gettext_lazy as _


class ModelAdminManager(models.Manager):
    def db_repr(self, model_admin: DjangoModelAdmin) -> "ModelAdmin":
        """
        Get database representation of a Django's ModelAdmin -- return
        a class ``dynamic_columns.models.ModelAdmin``. This class basically
        consists of 2 elements:

        * full qualified class name of ``model_admin``,
        * django.contrib.contenttype.models.ContentType reference of model registered
          for that model_admin instance.

        :param model_admin: ``django.contrib.admin.admin.ModelAdmin`` instance.

        :return: ``dynamic_columns.models.ModelAdmin`` instance, created fresh or from
        database.
        """
        cname = qual(model_admin.__class__)

        found = False
        for path in getattr(settings, "DYNAMIC_COLUMNS_ALLOWED_IMPORT_PATHS", []):
            if cname.startswith(path):
                found = True

        if not found:
            raise CodeAccessNotAllowed(
                f"Please add {cname} to your project's settings.py if you want to "
                f"use DynamicColumnsMixin for your {model_admin} classes -- "
                f"add it to a list ``DYNAMIC_COLUMNS_ALLOWED_IMPORT_PATHS``. "
            )

        return self.get_or_create(
            class_name=cname,
            model_ref=ContentType.objects.get_for_model(model_admin.model),
        )[0]

    def enable(self, model_admin: DjangoModelAdmin) -> "ModelAdmin":
        """
        Enable dynamic columns -- create an in-database representation
        of Django's ModelAdmin instance, create in-database representation
        of columns: enabled by default, which can be moved or disabled by end-user
        (``model_admin.list_display_default``) and disabled by default, which
        can be later enabled by end-user (``model_admin.list_display_allowed``),
        keeping forbidden columns (``model_admin.list_display_forbidden``) away.

        :returns: dynamic_columns.models.ModelAdmin
        """
        obj = self.db_repr(model_admin)

        # If there is a ``list_display`` setting on ``model_admin``, treat it
        # as ``list_display_default``.
        #
        # Unless it was not changed from the default settings, which at
        #  the time of this writing, contains only "__str__".
        #
        # In this case, if ``list_display_always`` is declared, we will skip it,
        # but it is not declared - we will not.
        #
        # This way we can still support the "old" ``list_display`` parameter, but avoid
        # displaying double columns in case it is not actually being used, in favor
        # of the new ``list_display_default`` and ``list_display_always``.
        #

        list_display = getattr(model_admin, "list_display", [])
        if list_display == DjangoModelAdmin.list_display:
            # Looks like ``list_display`` was not changed from default setting.
            # Is there ``list_display_always`` declared? If yes, empty
            # ``list_display`` variable
            if getattr(model_admin, "list_display_always", []):
                list_display = []

        # Sources of column names. ``list_display``, handled in a way described
        # above, ``list_display_default`` -- columns visible by default,
        # and ``list_display_allowed`` -- columns not visible by default, but
        # can be enabled later:

        column_sources = [
            # (column_source, column_enabled_defualt_value)
            (list_display, True),
            (getattr(model_admin, "list_display_default", []), True),
            (getattr(model_admin, "list_display_allowed", []), False),
        ]

        # Did you know, that instead of typing all the column names by yourself,
        # you could use a magic string "__all__"? This way you can get all the
        # columns in the model. But, could it be too broad? It could be. This is
        # why there is a setting ``list_display_forbidden`` which can exclude
        # some columns on a per-model basis, and there is also a configuration setting
        # ``DYNAMIC_COLUMNS_FORBIDDEN_COLUMN_NAMES``. Both those variables can
        # contain a list of regex that will be matched against column names.

        forbidden_columns_patterns = (
            # ``list_display_always`` are forbidden in the database - they are declared
            # in the code, they cannot be moved:
            getattr(model_admin, "list_display_forbidden", [])
            + getattr(settings, "DYNAMIC_COLUMNS_FORBIDDEN_COLUMN_NAMES", [])
        )

        list_display_always = getattr(model_admin, "list_display_always", [])

        def column_allowed(field_name):
            if field_name in list_display_always:
                return False

            for elem in forbidden_columns_patterns:
                if re.match(elem, field_name):
                    return False

            return True

        all_columns = set()

        db_max = ModelAdminColumn.objects.all().aggregate(max_cnt=Max("ordering"))
        cnt = (db_max["max_cnt"] or 0) + 1

        for column_source, default_value in column_sources:
            if column_source == "__all__":
                # Discover "all" columns
                columns = [
                    field.name
                    for field in model_admin.model._meta.fields
                    if column_allowed(field.name)
                ]
            else:
                # Got an exact list of column names in the source code:
                columns = column_source

            for column in [col for col in columns if column_allowed(col)]:
                all_columns.add(column)
                cnt += 1
                obj.modeladmincolumn_set.get_or_create(
                    col_name=column,
                    defaults={"ordering": cnt, "enabled": default_value},
                )

        # Remove stale columns from the database
        obj.modeladmincolumn_set.exclude(col_name__in=all_columns).delete()

        return obj


class ModelAdmin(models.Model):
    """
    In-database representation of a Django's ModelAdmin.

    Consists of 2 parameters actually.

    ``class_name`` is the class name of a Django's ModelAdmin,

    ``model_ref`` is a django.contrib.contenttypes.models.ContentType reference
    to a content type that is registered for that admin.

    In Django you can register a single ModelAdmin class for different models.
    This is no different here. You can create ModelAdmins with the same ``class_name``
    but for different ``model_ref``s and have different columns visible for every
    single one.
    """

    class_name = models.TextField()

    model_ref = models.ForeignKey(ContentType, on_delete=models.CASCADE)

    objects = ModelAdminManager()

    class Meta:
        unique_together = [("class_name", "model_ref")]
        ordering = ("class_name",)
        verbose_name = _("Model admin")
        verbose_name_plural = _("Model admins")

    def __str__(self):
        return self.class_name

    @cached_property
    def class_ref(self):
        """
        This function returns a reference to Django's ModelAdmin class, preferably
        the one from your project's code. But as the database could get modified
        in an unsafe manner, we will check if the module path for that ModelAdmin
        is defined in settings.py's ``DYNAMIC_COLUMNS_ALLOWED_IMPORT_PATHS``.
        """
        found = False
        for path in getattr(settings, "DYNAMIC_COLUMNS_ALLOWED_IMPORT_PATHS", []):
            if self.class_name.startswith(path):
                found = True

        if not found:
            raise CodeAccessNotAllowed(
                f"Path {self.class_name} not found in settings.DYNAMIC_COLUMNS_ALLOWED_IMPORT_PATHS"
            )

        return str_to_class(self.class_name)

    def get_list_display(self, model_admin, request):
        """This function returns the list of columns, in a specific order
        that should be displayed in a Django ModelAdmin's change list.
        """
        ret = OrderedSet()

        column_sources = [
            getattr(model_admin, "list_display_always", []),
            ModelAdmin.objects.db_repr(model_admin)
            .modeladmincolumn_set.filter(enabled=True)
            .values_list("col_name", flat=True),
        ]

        for column_source in column_sources:
            [ret.add(c) for c in column_source]

        return ret


class ModelAdminColumn(models.Model):
    """This is an in-database column representation of a given
    in-database ModelAdmin instance.

    It can be enabled or disabled -- visible or invisible.

    It also has an order in which it is displayed.
    """

    parent = models.ForeignKey(
        ModelAdmin, on_delete=models.CASCADE, verbose_name=_("Parent")
    )

    col_name = models.CharField(max_length=255, verbose_name=_("Column name"))

    enabled = models.BooleanField(default=True, verbose_name=_("Enabled"))
    ordering = models.PositiveSmallIntegerField(verbose_name=_("Ordering"))

    def __str__(self):
        ret = _("Column") + f' "{self.col_name}"'

        if self.parent_id:
            ret += _(" of model ") + f'"{self.parent.class_name}"'

        return ret

    class Meta:
        unique_together = [("parent", "col_name")]
        ordering = ("parent", "ordering")
        verbose_name = _("Model admin column")
        verbose_name_plural = _("Model admin columns")



from argparse import FileType

from denorm import denorms
from django.core.management import BaseCommand
from django.db import transaction

from ewaluacja2021.reports import load_data, rekordy


class Command(BaseCommand):
    """Odpina dyscypliny, bazujac na JSON"""

    def add_arguments(self, parser):
        parser.add_argument("wejscie", type=FileType("r"))

    def handle(self, wejscie, *args, **options):

        dane = load_data(wejscie)

        rekordy_danych = rekordy(dane)
        a = 0

        with transaction.atomic():
            for rekord in rekordy_danych.exclude(do_ewaluacji=True).exclude(slot=1):
                original = rekord.rekord.original
                # Odpinaj tylko w pracach, gdzie jest więcej jak jeden autor, ktoremu mozna odpiac:
                if (
                    original.autorzy_set.exclude(dyscyplina_naukowa_id=None)
                    .filter(przypieta=True)
                    .count()
                    > 1
                ):
                    original.autorzy_set.filter(
                        autor=rekord.autor, dyscyplina_naukowa=rekord.dyscyplina
                    ).update(przypieta=False)
                    a += 1

        print(f"Odpieto {a} dyscyplin; przeliczam...")
        denorms.flush()



# Generated by Django 2.1.10 on 2019-10-27 16:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0187_auto_20191027_1141'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='numer_w_serii',
            field=models.CharField(blank=True, max_length=512, null=True),
        ),
    ]



# -*- encoding: utf-8 -*-

from django.core.management import BaseCommand
from django.db import transaction

from bpp.management.commands.import_bpp import set_seq
from bpp.models import (
    Autor,
    Jednostka,
    Wydzial,
    Uczelnia,
    Zrodlo,
    Wydawnictwo_Zwarte,
    Wydawnictwo_Zwarte_Baza,
    Praca_Doktorska,
    Typ_Odpowiedzialnosci,
    Wydawnictwo_Ciagle,
    cache,
)


class Command(BaseCommand):
    help = "Zmienia typ odpowiedzialnosci autora na autora z redaktora w podanym charakterze formalnym"

    def add_arguments(self, parser):
        parser.add_argument("skrot")

    @transaction.atomic
    def handle(self, skrot, *args, **options):
        if cache.enabled():
            cache.disable()

        to_aut = Typ_Odpowiedzialnosci.objects.get(skrot="aut.")
        to_red = Typ_Odpowiedzialnosci.objects.get(skrot="red.")
        for klass in Wydawnictwo_Zwarte, Wydawnictwo_Ciagle:
            for elem in klass.objects.filter(charakter_formalny__skrot=skrot):
                for wza in elem.autorzy_set.filter(typ_odpowiedzialnosci=to_red):
                    wza.typ_odpowiedzialnosci = to_aut
                    wza.save()



# Generated by Django 3.0.13 on 2021-03-16 22:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0250_auto_20210315_2104"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
    ]



# Generated by Django 2.1.10 on 2019-10-30 04:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0189_auto_20191027_2158'),
    ]

    operations = [
        migrations.AddField(
            model_name='praca_doktorska',
            name='pmc_id',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='PubMed Central ID'),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='pmc_id',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='PubMed Central ID'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='pmc_id',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='PubMed Central ID'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='pmc_id',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='PubMed Central ID'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-28 11:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0142_auto_20180624_2245'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='wydruk_logo_szerokosc',
            field=models.SmallIntegerField(default=250, help_text='Podaj wartość w pikselach. Wysokość zostanie przeskalowanaproporcjonalnie. ', verbose_name='Szerokość logo na wydrukach'),
        ),
    ]



from rest_framework import viewsets

from api_v1.serializers.struktura import (
    JednostkaSerializer,
    WydzialSerializer,
    UczelniaSerializer,
)
from bpp.models import Jednostka, Wydzial, Uczelnia


class JednostkaViewSet(viewsets.ReadOnlyModelViewSet):
    queryset = Jednostka.objects.all()
    serializer_class = JednostkaSerializer


class WydzialViewSet(viewsets.ReadOnlyModelViewSet):
    queryset = Wydzial.objects.all()
    serializer_class = WydzialSerializer


class UczelniaViewSet(viewsets.ReadOnlyModelViewSet):
    queryset = Uczelnia.objects.all()
    serializer_class = UczelniaSerializer



from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):
    dependencies = [
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0001_widok_rozbieznosci", app_name="rozbieznosci_dyscyplin")
        ),

    ]



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0049_auto_20160920_0333'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='tytul',
            options={'ordering': ('skrot',), 'verbose_name': 'tytu\u0142', 'verbose_name_plural': 'tytu\u0142y'},
        ),
        migrations.RemoveField(
            model_name='jednostka',
            name='rozpoczecie_funkcjonowania',
        ),
        migrations.RemoveField(
            model_name='jednostka',
            name='zakonczenie_funkcjonowania',
        ),
        migrations.RemoveField(
            model_name='wydzial',
            name='rozpoczecie_funkcjonowania',
        ),
        migrations.RemoveField(
            model_name='wydzial',
            name='zakonczenie_funkcjonowania',
        ),
    ]



# Generated by Django 3.0.14 on 2022-07-04 06:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0321_aktualna_jednostka_moze_byc_zadna"),
    ]

    operations = [
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
    ]



from notifications.core import (
    get_obj_from_channel_name,
    convert_obj_to_channel_name,
)
import pytest


@pytest.mark.django_db
def test_convert_obj_to_channel_name(wydawnictwo_zwarte):
    assert convert_obj_to_channel_name(wydawnictwo_zwarte).startswith(
        "bpp.wydawnictwo_zwarte-"
    )


@pytest.mark.django_db
def test_get_obj_from_channel_name(wydawnictwo_zwarte):
    pk = wydawnictwo_zwarte.pk
    rec = get_obj_from_channel_name(f"bpp.wydawnictwo_zwarte-{pk}")
    assert rec == wydawnictwo_zwarte



from django.db import models

from bpp.models import NazwaISkrot


class Kierunek_Studiow(NazwaISkrot):
    wydzial = models.ForeignKey("bpp.Wydzial", on_delete=models.PROTECT)

    opis = models.TextField(blank=True, null=True)
    adnotacje = models.TextField(blank=True, null=True)

    class Meta:
        verbose_name = "kierunek studiów"
        verbose_name_plural = "kierunki studiów"
        ordering = ("nazwa",)
        app_label = "bpp"



# -*- encoding: utf-8 -*-

from django.conf import settings
from django.core.management import BaseCommand

from bpp.models import Patent_Autor, Wydawnictwo_Ciagle_Autor, Wydawnictwo_Zwarte_Autor


class Command(BaseCommand):
    """
    Polecenie porządkujące kolejności autorów

    Ustaw kolejność pierwszego autora na „0”, uprządkuj następujące po sobie
    kolejności, upewnij się, że nie ma luk, etc…
    """

    help = (
        'Upewnia sie, ze wartosc pola "kolejnosc" dla autorow wydawnictw ciaglych '
        "i zwartych jest poprawna, tzn. zaczyna sie od zera i jest ponumerowana w "
        "sposob ciagly."
    )

    # NIE robimy tego w transakcji, aby nie przyblokować bazy danyc na dłuższy czas
    # @transaction.atomic
    def handle(self, *args, **options):
        # Jeżeli będziemy to robić z włączonym cache, dojdzie do przyblokowania
        # kolejki Celery. Realnie renumeracja kolejności nie pociąga za sobą zmiany
        # w opisach bibliograficznych, więc musimy to wyłączyć:
        pass

        # W tym poleceniu chodzi wyłącznie o przypilnowanie prawidłowej kolejności autorów.
        # Wywołanie błedu w sytuacji, gdy autorzy mają zaznaczone afiliacje na obce jednostki
        # nie ma znaczenia, zatem:
        _orig_value = getattr(settings, "BPP_WALIDUJ_AFILIACJE_AUTOROW", True)

        try:
            setattr(settings, "BPP_WALIDUJ_AFILIACJE_AUTOROW", False)

            for klass in [
                Wydawnictwo_Ciagle_Autor,
                Wydawnictwo_Zwarte_Autor,
                Patent_Autor,
            ]:
                if options["verbosity"] >= 2:
                    print(klass)

                old_id = None
                # Taki porządek sortowania, bo jeżeli się trafią dwa rekordy z tą
                # samą kolejnością, to ten o mniejszym ID ma pierwszeństwo
                q = klass.objects.all().order_by("rekord_id", "kolejnosc", "id")

                for elem in q:

                    if old_id != elem.rekord_id:
                        old_id = elem.rekord_id
                        next_kolejnosc = 0
                        pre = "---"

                    if next_kolejnosc != elem.kolejnosc:
                        if options["verbosity"] >= 2:
                            if pre is not None:
                                print(pre)
                            pre = None
                            print(
                                elem.rekord_id,
                                elem.id,
                                "kolejnosc",
                                elem.kolejnosc,
                                ":=",
                                next_kolejnosc,
                            )
                        elem.kolejnosc = next_kolejnosc
                        elem.save()

                    next_kolejnosc += 1
        finally:
            setattr(settings, "BPP_WALIDUJ_AFILIACJE_AUTOROW", _orig_value)



from decimal import Decimal

import pytest
from django.core.files.uploadedfile import SimpleUploadedFile

from bpp.models import Zrodlo
from import_list_if.models import ImportListIf


@pytest.fixture
def testdata_xlsx_path():
    import os

    return os.path.join(os.path.dirname(__file__), "testdata1.xlsx")


def import_list_if_factory(user, path, rok):
    i = ImportListIf(owner=user, rok=rok)
    i.plik_xls = SimpleUploadedFile(
        "import_dyscyplin_zrodel_przyklad.xlsx", open(path, "rb").read()
    )
    i.save()
    return i


@pytest.fixture
def import_list_if(admin_user, testdata_xlsx_path, zrodlo, rok):
    zrodlo.nazwa = "Gazeta"
    zrodlo.save()

    return import_list_if_factory(admin_user, testdata_xlsx_path, rok)


def test_ImportListIF_perform(import_list_if, rok):
    import_list_if.perform()
    assert import_list_if.importlistifrow_set.count() == 4
    assert Zrodlo.objects.get(nazwa="Gazeta").punktacja_zrodla_set.get(
        rok=rok
    ).impact_factor == Decimal("70.67")


def test_ImportListIF_on_reset(import_list_if, rok):
    import_list_if.on_reset()
    assert True


def test_ImportListIF_get_details_set(import_list_if, rok):
    import_list_if.get_details_set()
    assert True



from crispy_forms.helper import FormHelper
from crispy_forms.layout import Hidden
from crispy_forms_foundation.layout import ButtonHolder, Fieldset, Layout, Submit

from django.contrib.auth import REDIRECT_FIELD_NAME
from django.contrib.auth.forms import AuthenticationForm


class MyAuthenticationForm(AuthenticationForm):
    def __init__(self, request=None, *args, **kw):
        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Zaloguj się!",
                "username",
                "password",
                Hidden(
                    REDIRECT_FIELD_NAME, request.GET.get(REDIRECT_FIELD_NAME, "/bpp/")
                ),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Zaloguj się",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )
        AuthenticationForm.__init__(self, request, *args, **kw)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-17 07:23
from __future__ import unicode_literals

from django.db import migrations, models

from bpp.models.abstract import wez_zakres_stron, parse_informacje


def przerzuc_dane(apps, schema_editor):
    for model in ['Wydawnictwo_Ciagle', 'Wydawnictwo_Zwarte',
                  'Patent', 'Praca_Doktorska', 'Praca_Habilitacyjna']:
        klass = apps.get_model("bpp", model)
        for elem in klass.objects.all():

            if hasattr(elem, 'strony'):
                if elem.szczegoly:
                    s = wez_zakres_stron(elem.szczegoly)
                    if not elem.strony:
                        if s != elem.strony:
                            elem.strony = s
                            changed = True

            if elem.informacje is not None:
                tom = parse_informacje(elem.informacje, "tom")
                nr_zeszytu = parse_informacje(elem.informacje, "numer")

                if hasattr(elem, 'tom'):
                    if not elem.tom and tom:
                        if tom != elem.tom:
                            elem.tom = tom
                            chagned = True

                if hasattr(elem, 'nr_zeszytu'):
                    if not elem.nr_zeszytu and nr_zeszytu:
                        if nr_zeszytu != elem.nr_zeszytu:
                            elem.nr_zeszytu = nr_zeszytu
                            changed = True

            if changed:
                elem.save()


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0083_afiliuje_zatrudniony'),
    ]

    operations = [
        migrations.AddField(
            model_name='patent',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Szczegóły\' w chwili importu. Aby uniknąć sytuacji, gdy wskutek\n        błędnego wprowadzenia tekstu do pola "Szczegóły" informacja ta nie \n        będzie mogła być wyekstrahowana z tego pola, kliknij przycisk \n        "Uzupełnij", aby spowodować uzupełnienie tego pola na podstawie\n        pola "Szcegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='patent',
            name='tom',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Informacje\'. Kliknięcie przycisku "Uzupełnij" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Szczegóły\' w chwili importu. Aby uniknąć sytuacji, gdy wskutek\n        błędnego wprowadzenia tekstu do pola "Szczegóły" informacja ta nie \n        będzie mogła być wyekstrahowana z tego pola, kliknij przycisk \n        "Uzupełnij", aby spowodować uzupełnienie tego pola na podstawie\n        pola "Szcegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='tom',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Informacje\'. Kliknięcie przycisku "Uzupełnij" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Szczegóły\' w chwili importu. Aby uniknąć sytuacji, gdy wskutek\n        błędnego wprowadzenia tekstu do pola "Szczegóły" informacja ta nie \n        będzie mogła być wyekstrahowana z tego pola, kliknij przycisk \n        "Uzupełnij", aby spowodować uzupełnienie tego pola na podstawie\n        pola "Szcegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='tom',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Informacje\'. Kliknięcie przycisku "Uzupełnij" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='nr_zeszytu',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Informacje\'. Kliknięcie przycisku "Uzupełnij" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Szczegóły\' w chwili importu. Aby uniknąć sytuacji, gdy wskutek\n        błędnego wprowadzenia tekstu do pola "Szczegóły" informacja ta nie \n        będzie mogła być wyekstrahowana z tego pola, kliknij przycisk \n        "Uzupełnij", aby spowodować uzupełnienie tego pola na podstawie\n        pola "Szcegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='tom',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Informacje\'. Kliknięcie przycisku "Uzupełnij" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Szczegóły\' w chwili importu. Aby uniknąć sytuacji, gdy wskutek\n        błędnego wprowadzenia tekstu do pola "Szczegóły" informacja ta nie \n        będzie mogła być wyekstrahowana z tego pola, kliknij przycisk \n        "Uzupełnij", aby spowodować uzupełnienie tego pola na podstawie\n        pola "Szcegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='tom',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola \'Informacje\'. Kliknięcie przycisku "Uzupełnij" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ', max_length=50, null=True),
        ),

        migrations.RunPython(
            przerzuc_dane,
            migrations.RunPython.noop
        )
    ]



# -*- encoding: utf-8 -*-
import warnings
from decimal import Decimal
import os
import shutil
import tempfile
import sys

from celeryui.registry import ReportAdapter
from django.contrib.contenttypes.models import ContentType
from django.core.files import File
from django.db.models import Q, Sum
from django.template.loader import render_to_string
from django.utils import safestring
from django_tables2 import Column, A, Table

from bpp.models import (
    Autor,
    Typ_KBN,
    Rekord,
    Charakter_Formalny,
    Zasieg_Zrodla,
    Redakcja_Zrodla,
)

# from bpp.models.cache import cache_znajdz_autora_i_typ
from bpp.models.praca_habilitacyjna import Publikacja_Habilitacyjna
from bpp.models.system import Typ_Odpowiedzialnosci, Jezyk
from bpp.reports import addToRegistry
from bpp.util import Getter
from bpp.views.raporty.raport_aut_jed_common import (
    SumyImpactKbnMixin,
    sumpk_kc,
    sumif_kc,
)


class TabelaRaportuKomisjiCentralnejMixin(Table):
    lp = Column("Lp.", A("id"), empty_values=(), orderable=False)

    def __init__(self, *args, **kw):
        super(TabelaRaportuKomisjiCentralnejMixin, self).__init__(*args, **kw)
        self.counter = 0

    def render_lp(self, record):
        self.counter += 1
        return "%d." % self.counter


class TabelkaZImpactem(TabelaRaportuKomisjiCentralnejMixin, SumyImpactKbnMixin, Table):
    class Meta:
        attrs = {"class": "z_ramka"}
        template_name = "raporty/raport_komisji_centralnej/tabela_ia.html"
        per_page = sys.maxsize
        empty_text = "Brak takich rekordów."
        sequence = (
            "lp",
            "rok",
            "opis_bibliograficzny_cache",
            "impact_factor",
            "punkty_kbn",
        )

    rok = Column("Rok", orderable=False)
    opis_bibliograficzny_cache = Column(
        "Opis", orderable=False, attrs={"td": {"width": "70%"}}
    )

    def render_opis_bibliograficzny_cache(self, record):
        return safestring.mark_safe(record.opis_bibliograficzny_cache)


class TabelkaBezImpactu(TabelkaZImpactem):
    class Meta:
        template_name = "raporty/raport_komisji_centralnej/tabela_ib.html"
        sequence = ("lp", "rok", "opis_bibliograficzny_cache", "punkty_kbn")
        exclude = ["impact_factor"]
        attrs = {"class": "z_ramka"}


class Tabelka9Mixin(Table):
    impact_factor = Column(
        "IF", footer=sumif_kc, attrs={"td": {"align": "right"}}, orderable=False,
    )
    punkty_kbn = Column(
        "PK (MNiSzW)",
        footer=sumpk_kc,
        attrs={"td": {"align": "right"}},
        orderable=False,
    )

    def render_impact_factor(self, record):
        return record.kc_impact_factor or record.impact_factor

    def render_punkty_kbn(self, record):
        return record.kc_punkty_kbn or record.punkty_kbn


class TabelkaNr9A(Tabelka9Mixin, TabelkaZImpactem, Table):
    class Meta:
        template_name = "raporty/raport_komisji_centralnej/tabela_ia.html"
        attrs = {"class": "z_ramka"}
        sequence = (
            "lp",
            "rok",
            "opis_bibliograficzny_cache",
            "impact_factor",
            "punkty_kbn",
        )

        pass


class TabelkaNr9B(Tabelka9Mixin, TabelkaBezImpactu, Table):
    class Meta:
        template_name = "raporty/raport_komisji_centralnej/tabela_ib.html"
        attrs = {"class": "z_ramka"}
        sequence = (
            "lp",
            "rok",
            "opis_bibliograficzny_cache",
            "punkty_kbn",
        )
        exclude = [
            "impact_factor",
        ]

        pass


class RokHabilitacjiNiePodany(Exception):
    pass


def get_queries(autor, przed_habilitacja=True, rok_habilitacji=None):
    base_query = Rekord.objects.prace_autora(autor)

    if przed_habilitacja:
        if rok_habilitacji is not None:
            base_query = base_query.filter(rok__lte=rok_habilitacji)
    else:
        if rok_habilitacji is None:
            # Jeżeli chcesz raport PO habilitacji, ale autor NIE MA habilitacji,
            # to podnieś wyjątek:
            raise RokHabilitacjiNiePodany

        base_query = base_query.filter(rok__gt=rok_habilitacji)

    typ_kbn = Getter(Typ_KBN)
    typ_odpowiedzialnosci = Getter(Typ_Odpowiedzialnosci)
    charakter = Getter(Charakter_Formalny)
    zasieg = Getter(Zasieg_Zrodla, "nazwa")
    jezyk = Getter(Jezyk)

    ac = charakter.AC

    order_if = ("rok", "-impact_factor", "zrodlo")
    order_if_kc = ("rok", "-kc_impact_factor", "-impact_factor", "zrodlo")
    order_kbn = ("rok", "-punkty_kbn", "zrodlo")

    kw1 = dict(typ_kbn=typ_kbn.PO, charakter_formalny=ac)
    kw2 = dict(typ_kbn=typ_kbn.CR, charakter_formalny=ac)
    kw3 = dict(typ_kbn=typ_kbn.PP, charakter_formalny=ac)

    kw9 = dict(charakter_formalny=charakter.Supl)
    kw10 = dict(charakter_formalny=charakter.L)
    kw11 = dict(typ_kbn=typ_kbn.PW)

    impact = dict(impact_factor__gt=0)
    no_impact = dict(impact_factor=0)

    pkt_5_charaktery = []
    for skrot in [
        "BR",
        "FRG",
        "IN",
        "KOM",
        "PAT",
        "PZ",
        "SKR",
        "TŁ",
        "DE",
        "PRZ",
        "ZRZ",
        "R",
    ]:
        try:
            pkt_5_charaktery.append(Charakter_Formalny.objects.get(skrot__upper=skrot))
        except Charakter_Formalny.DoesNotExist:
            warnings.warn(
                "Brak charakteru formalnego %s dla punktu 5 raportu dla komisji centralnej"
                % skrot
            )
        # charakter.BR, charakter.frg, charakter.IN, charakter.KOM,
        # charakter.PAT, charakter.PZ, charakter.SKR, charakter['TŁ'],
        # charakter.DE, charakter.PRZ, charakter.ZRZ, charakter.R

    praca_habilitacyjna_content_type = ContentType.objects.get(
        app_label="bpp", model="praca_habilitacyjna"
    ).pk

    publikacje_habilitacyjne = Q(
        id__in=[
            (praca_habilitacyjna_content_type, pk.pk)
            for pk in Publikacja_Habilitacyjna.objects.filter().distinct().only("id")
        ]
    )

    try:
        jezyk_angielski = jezyk["ang."]
    except Jezyk.DoesNotExist:
        jezyk_angielski = jezyk["ENG"]

    ret = {
        "1a": base_query.filter(**dict(impact, **kw1)).order_by(*order_if),
        "1b": base_query.filter(**dict(no_impact, **kw1)).order_by(*order_kbn),
        "2a": base_query.filter(**dict(impact, **kw2)).order_by(*order_if),
        "2b": base_query.filter(**dict(no_impact, **kw2)).order_by(*order_kbn),
        "3a": base_query.filter(**dict(impact, **kw3)).order_by(*order_if),
        "3b": base_query.filter(**dict(no_impact, **kw3)).order_by(*order_kbn),
        "4c1": Rekord.objects.prace_autor_i_typ(autor, "aut.")
        .filter(
            charakter_formalny__in=[charakter.KSZ, charakter.H], jezyk=jezyk_angielski
        )
        .exclude(publikacje_habilitacyjne),
        "4c2": Rekord.objects.prace_autor_i_typ(autor, "aut.")
        .filter(charakter_formalny__in=[charakter.KSZ, charakter.KSP, charakter.H])
        .exclude(jezyk=jezyk_angielski)
        .exclude(publikacje_habilitacyjne),
        "5": base_query.filter(
            Q(charakter_formalny__in=pkt_5_charaktery)
            | Q(typ_kbn=typ_kbn["000"], charakter_formalny=charakter.AC)
            | Q(typ_kbn=typ_kbn.PNP)
            |
            # Habilitacja-składak
            publikacje_habilitacyjne,
        ).exclude(charakter_formalny__in=[charakter.PSZ, charakter.ZSZ]),
        "6a": Redakcja_Zrodla.objects.filter(
            redaktor=autor, zrodlo__zasieg=zasieg["krajowy"]
        )
        .values_list("zrodlo_id")
        .distinct(),
        "6b": Redakcja_Zrodla.objects.filter(
            redaktor=autor, zrodlo__zasieg=zasieg["międzynarodowy"]
        )
        .values_list("zrodlo_id")
        .distinct(),
        "7a": Rekord.objects.prace_autor_i_typ(autor, "red.").filter(
            jezyk=jezyk_angielski, charakter_formalny=charakter.KSZ
        ),
        "7b": Rekord.objects.prace_autor_i_typ(autor, "red.")
        .filter(charakter_formalny__in=[charakter.KSP, charakter.KSZ])
        .exclude(jezyk=jezyk_angielski),
        "8a": base_query.filter(charakter_formalny=charakter.ZSZ),
        "8b": base_query.filter(charakter_formalny=charakter.PSZ),
        "9a": base_query.filter(
            Q(Q(impact_factor__gt=0) | Q(kc_impact_factor__gt=0)), **kw9
        ).order_by(*order_if_kc),
        "9b": base_query.filter(
            Q(Q(impact_factor=0) & Q(Q(kc_impact_factor=0) | Q(kc_impact_factor=None))),
            **kw9
        ).order_by(*order_kbn),
        "10a": base_query.filter(**dict(impact, **kw10)).order_by(*order_if),
        "10b": base_query.filter(**dict(no_impact, **kw10)).order_by(*order_if),
        "11a": base_query.filter(**dict(impact, **kw11)).order_by(*order_if),
        "11b": base_query.filter(**dict(no_impact, **kw11)).order_by(*order_if),
        "IIIpat": base_query.filter(charakter_formalny=charakter.PAT),
    }
    return ret


class RaportKomisjiCentralnej:
    def __init__(self, autor, przed_habilitacja=True, rok_habilitacji=None):
        """

        :ptype autor: bpp.models.Autor
        :param przed_habilitacja: domyślnie wygeneruj raport dla autora przed
        habilitacją; jeżeli ten parametr jest False, zostaną wygenerowane dane
        dla autora PO habilitacji.
        """
        queries = get_queries(autor, przed_habilitacja, rok_habilitacji)

        self.dct = {}

        if rok_habilitacji is None:
            self.dct["rodzaj_dorobku"] = ""
            self.dct["stopien"] = "stopnia naukowego doktora habilitowanego"
        else:
            self.dct["stopien"] = "tytułu profesora"
            if przed_habilitacja:
                self.dct["rodzaj_dorobku"] = "Dorobek przedhabilitacyjny"
            else:
                self.dct["rodzaj_dorobku"] = "Dorobek pohabilitacyjny"

        impact_od_1_do_3 = 0
        kbn_od_1_do_3 = 0

        for key in ["1a", "1b", "2a", "2b", "3a", "3b"]:
            result = queries[key].aggregate(Sum("impact_factor"), Sum("punkty_kbn"))
            impact_od_1_do_3 += result["impact_factor__sum"] or 0
            kbn_od_1_do_3 += result["punkty_kbn__sum"] or 0

        liczba_streszczen_mnar = queries["8a"].count()
        liczba_streszczen_kraj = queries["8b"].count()
        liczba_streszczen = liczba_streszczen_kraj + liczba_streszczen_mnar

        def zsumuj(indeksy_zapytan):
            return sum([queries[x].count() for x in indeksy_zapytan])

        liczba_prac_I = zsumuj(["1a", "1b"])
        liczba_prac_II = zsumuj(["2a", "2b"])
        liczba_prac_III = zsumuj(["3a", "3b"])
        liczba_prac_IX = zsumuj(["9a", "9b"])

        liczba_prac_IVc1 = queries["4c1"].count()
        liczba_prac_IVc2 = queries["4c2"].count()

        self.dct.update(
            {
                "autor": autor,
                "extra": "TODO: extra",
                "liczba_prac_I": liczba_prac_I,
                "liczba_prac_II": liczba_prac_II,
                "liczba_prac_III": liczba_prac_III,
                "liczba_prac_IX": liczba_prac_IX,
                "tabela_1a": TabelkaZImpactem(queries["1a"]),
                "tabela_1b": TabelkaBezImpactu(queries["1b"]),
                "tabela_2a": TabelkaZImpactem(queries["2a"]),
                "tabela_2b": TabelkaBezImpactu(queries["2b"]),
                "tabela_3a": TabelkaZImpactem(queries["3a"]),
                "tabela_3b": TabelkaBezImpactu(queries["3b"]),
                "impact_od_1_do_3": impact_od_1_do_3,
                "kbn_od_1_do_3": kbn_od_1_do_3,
                "liczba_prac_IVc1": liczba_prac_IVc1,
                "liczba_prac_IVc2": liczba_prac_IVc2,
                "liczba_prac_IVc": liczba_prac_IVc2 + liczba_prac_IVc1,
                "liczba_prac_5": queries["5"].count(),
                "liczba_redaktor_mnar": queries["6a"].count(),
                "liczba_redaktor_kraj": queries["6b"].count(),
                "liczba_redaktor_wieloautorskich_ang": queries["7a"].count(),
                "liczba_redaktor_wieloautorskich_pol": queries["7b"].count(),
                "liczba_streszczen_kraj": liczba_streszczen_kraj,
                "liczba_streszczen_mnar": liczba_streszczen_mnar,
                "liczba_streszczen": liczba_streszczen,
                "tabela_9a": TabelkaNr9A(queries["9a"]),
                "tabela_9b": TabelkaNr9B(queries["9b"]),
                "tabela_10a": TabelkaZImpactem(queries["10a"]),
                "tabela_10b": TabelkaBezImpactu(queries["10b"]),
                "suma_10": queries["10a"].count() + queries["10b"].count(),
                "tabela_11a": TabelkaZImpactem(queries["11a"]),
                "tabela_11b": TabelkaBezImpactu(queries["11b"]),
                "suma_11": queries["11a"].count() + queries["11b"].count(),
                "IIIpat": queries["IIIpat"],
            }
        )

        self.rendered = False

    def make_prace(self):

        try:
            return render_to_string(
                "raporty/raport_komisji_centralnej/raport_bazowy.html", context=self.dct
            )
        finally:
            self.rendered = True

    def policz_sumy(self):
        if not self.rendered:
            # Wyrenderuj, żeby tabelki zsumowały wartości i żeby te wartości
            #  zostały zapisane na obiektach:
            self.make_prace()

        def sum_dict(*prefixes):
            count = 0
            impact_factor = Decimal("0.00")
            punkty_kbn = Decimal("0.00")

            for prefix in prefixes:
                tabela = self.dct["tabela_%s" % prefix]
                count += tabela.counter
                if hasattr(tabela, "sum_impact"):
                    impact_factor += tabela.sum_impact
                elif "impact_factor" in tabela.columns:
                    impact_factor += tabela.columns["impact_factor"].footer

                if hasattr(tabela, "sum_punkty_kbn"):
                    punkty_kbn += tabela.sum_punkty_kbn
                elif "punkty_kbn" in tabela.columns:
                    punkty_kbn += tabela.columns["punkty_kbn"].footer

            return dict(count=count, punkty_kbn=punkty_kbn, impact_factor=impact_factor)

        dct = {
            "suma_1": sum_dict("1a", "1b"),
            "suma_2": sum_dict("2a", "2b"),
            "suma_3": sum_dict("3a", "3b"),
            "suma_9": sum_dict("9a", "9b"),
            "suma_10": sum_dict("10a", "10b"),
            "suma_11": sum_dict("11a", "11b"),
            #'suma_4': sum_dict('4a', '4b'),
            "suma_5": dict(count=self.dct["liczba_prac_5"]),
            "suma_8": dict(count=self.dct["liczba_streszczen"]),
            "stopien": self.dct["stopien"],
            "rodzaj_dorobku": self.dct["rodzaj_dorobku"],
            "autor": self.dct["autor"],
        }

        return dct

    def punktacja_sumaryczna(self, partial=False):
        dct = self.policz_sumy()

        template_name = "raporty/raport_komisji_centralnej/" "punktacja_pojedyncza.html"
        if partial:
            template_name = "raporty/raport_komisji_centralnej/punktacja.html"

        return render_to_string(template_name, dct)


def make_report_zipfile(autor_id, rok_habilitacji):
    katalog = tempfile.mkdtemp("-bpp-kc-raport")
    current_dir = os.getcwd()

    zipname = None
    ret_path = None

    try:
        autor = Autor.objects.get(pk=autor_id)

        os.chdir(katalog)
        subdir = autor.slug + " - raport Komisji Centralnej"
        os.makedirs(subdir)
        os.chdir(subdir)

        base_fn = autor.slug
        filenames = []

        def save_encoded(fn, data):
            f = open(fn, "wb")
            f.write(data.encode("utf-8"))
            f.close()

        def fn(base, n, postfix):
            return "%s-%s-%s.html" % (base, n, postfix)

        if rok_habilitacji is not None:
            for postfix, arg in [("przed", True), ("po", False)]:
                raport = RaportKomisjiCentralnej(autor, arg, rok_habilitacji)

                save_encoded(fn(base_fn, "prace", postfix), raport.make_prace())

                # Zapisz "tymczasowy" pliki z punktacją, który później
                # zostaną połączony z drugim plikiem we wspólny raport:
                save_encoded(
                    fn(base_fn, "punktacja", postfix),
                    raport.punktacja_sumaryczna(partial=True),
                )

            dct = {"autor": raport.dct["autor"], "stopien": raport.dct["stopien"]}
            for postfix in ["przed", "po"]:
                dct[postfix] = open(fn(base_fn, "punktacja", postfix), "rb").read()

            data = render_to_string(
                "raporty/raport_komisji_centralnej/punktacja_podwojna.html", dct
            )

            f = open(fn(base_fn, "punktacja", "sumaryczna"), "wb")
            f.write(data.encode("utf-8"))
            f.close()

        else:
            raport = RaportKomisjiCentralnej(autor, True)
            for fun, n in [
                ("make_prace", "prace"),
                ("punktacja_sumaryczna", "punktacja"),
            ]:
                fn = "%s-%s.html" % (base_fn, n)
                data = getattr(raport, fun)()
                save_encoded(fn, data)

        zipname = "%s.zip" % subdir

        os.chdir("..")
        os.system('zip --quiet -r "%s" "%s" ' % (zipname, subdir))
        shutil.rmtree(subdir)

        return os.path.abspath(zipname)

    finally:
        os.chdir(current_dir)
        pass


class Raport_Dla_Komisji_Centralnej(ReportAdapter):
    slug = "raport-dla-komisji-centralnej"

    def _get_title(self):
        try:
            a = str(Autor.objects.get(pk=self.original.arguments["autor"]))
        except Autor.DoesNotExist:
            a = "(autor usunięty)"
        return "Raport dla Komisji Centralnej - %s" % a

    title = property(_get_title)

    def perform(self):
        try:
            rok_habilitacji = int(self.original.arguments["rok_habilitacji"])
        except (TypeError, ValueError):
            rok_habilitacji = None

        zipname = make_report_zipfile(
            autor_id=self.original.arguments["autor"], rok_habilitacji=rok_habilitacji
        )
        from django.core.files import File as FileWrapper

        self.original.file.save(
            os.path.basename(zipname),
            File(file=FileWrapper(open(zipname, "rb"), zipname)),
        )
        os.unlink(zipname)


addToRegistry(Raport_Dla_Komisji_Centralnej)



from dal import autocomplete
from django import forms
from taggit.forms import TextareaTagWidget

from ..models import Autor, Jednostka, Praca_Doktorska
from .actions import ustaw_po_korekcie, ustaw_przed_korekta, ustaw_w_trakcie_korekty
from .core import BaseBppAdminMixin
from .element_repozytorium import Element_RepozytoriumInline
from .filters import OstatnioZmienionePrzezFilter, UtworzonePrzezFilter
from .grant import Grant_RekorduInline
from .helpers import (
    ADNOTACJE_Z_DATAMI_FIELDSET,
    DWA_TYTULY,
    EKSTRA_INFORMACJE_DOKTORSKA_HABILITACYJNA_FIELDSET,
    MODEL_OPCJONALNIE_NIE_EKSPORTOWANY_DO_API_FIELDSET,
    MODEL_PUNKTOWANY_FIELDSET,
    MODEL_PUNKTOWANY_KOMISJA_CENTRALNA_FIELDSET,
    MODEL_TYPOWANY_BEZ_CHARAKTERU_FIELDSET,
    MODEL_Z_ISBN,
    MODEL_Z_OPLATA_ZA_PUBLIKACJE_FIELDSET,
    MODEL_Z_ROKIEM,
    MODEL_ZE_SZCZEGOLAMI,
    NIZSZE_TEXTFIELD_Z_MAPA_ZNAKOW,
    POZOSTALE_MODELE_FIELDSET,
    AdnotacjeZDatamiMixin,
    DomyslnyStatusKorektyMixin,
    Wycinaj_W_z_InformacjiMixin,
)
from .wydawnictwo_ciagle import CleanDOIWWWPublicWWWMixin

from django.contrib import admin

# Proste tabele


DOKTORSKA_FIELDS = (
    DWA_TYTULY
    + MODEL_ZE_SZCZEGOLAMI
    + (
        "oznaczenie_wydania",
        "miejsce_i_rok",
        "wydawca",
        "wydawca_opis",
        "autor",
        "jednostka",
        "promotor",
    )
    + MODEL_Z_ISBN
    + MODEL_Z_ROKIEM
)


class Praca_Doktorska_Habilitacyjna_Admin_Base(
    AdnotacjeZDatamiMixin, BaseBppAdminMixin, admin.ModelAdmin
):
    formfield_overrides = NIZSZE_TEXTFIELD_Z_MAPA_ZNAKOW
    actions = [ustaw_po_korekcie, ustaw_w_trakcie_korekty, ustaw_przed_korekta]

    list_display = [
        "tytul_oryginalny",
        "autor",
        "jednostka",
        "wydawca",
        "wydawca_opis",
        "typ_kbn",
        "ostatnio_zmieniony",
    ]
    list_select_related = [
        "autor",
        "autor__tytul",
        "jednostka",
        "wydawca",
        "jednostka__wydzial",
        "typ_kbn",
    ]

    search_fields = [
        "tytul",
        "tytul_oryginalny",
        "szczegoly",
        "uwagi",
        "informacje",
        "slowa_kluczowe__name",
        "rok",
        "www",
        "wydawca_opis",
        "wydawca__nazwa",
        "redakcja",
        "autor__tytul__nazwa",
        "jednostka__nazwa",
        "adnotacje",
        "id",
        "doi",
        "pbn_uid__pk",
    ]

    list_filter = [
        "status_korekty",
        "recenzowana",
        "typ_kbn",
        OstatnioZmienionePrzezFilter,
        UtworzonePrzezFilter,
    ]


class Praca_DoktorskaForm(
    Wycinaj_W_z_InformacjiMixin, CleanDOIWWWPublicWWWMixin, forms.ModelForm
):
    autor = forms.ModelChoiceField(
        queryset=Autor.objects.all(),
        widget=autocomplete.ModelSelect2(url="bpp:autor-z-uczelni-autocomplete"),
    )

    jednostka = forms.ModelChoiceField(
        queryset=Jednostka.objects.all(),
        widget=autocomplete.ModelSelect2(url="bpp:jednostka-autocomplete"),
    )

    promotor = forms.ModelChoiceField(
        queryset=Autor.objects.all(),
        widget=autocomplete.ModelSelect2(url="bpp:autor-z-uczelni-autocomplete"),
    )

    status_korekty = DomyslnyStatusKorektyMixin.status_korekty

    class Meta:
        model = Praca_Doktorska
        fields = "__all__"
        widgets = {
            "slowa_kluczowe": TextareaTagWidget(attrs={"rows": 2}),
        }


class Praca_DoktorskaAdmin(Praca_Doktorska_Habilitacyjna_Admin_Base):
    form = Praca_DoktorskaForm

    fieldsets = (
        ("Praca doktorska", {"fields": DOKTORSKA_FIELDS}),
        EKSTRA_INFORMACJE_DOKTORSKA_HABILITACYJNA_FIELDSET,
        MODEL_TYPOWANY_BEZ_CHARAKTERU_FIELDSET,
        MODEL_PUNKTOWANY_FIELDSET,
        MODEL_PUNKTOWANY_KOMISJA_CENTRALNA_FIELDSET,
        POZOSTALE_MODELE_FIELDSET,
        ADNOTACJE_Z_DATAMI_FIELDSET,
        MODEL_OPCJONALNIE_NIE_EKSPORTOWANY_DO_API_FIELDSET,
        MODEL_Z_OPLATA_ZA_PUBLIKACJE_FIELDSET,
    )

    inlines = (
        Grant_RekorduInline,
        Element_RepozytoriumInline,
    )


admin.site.register(Praca_Doktorska, Praca_DoktorskaAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-11-25 11:02
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0149_ranking_afiliacje'),
    ]

    operations = [
        migrations.AlterField(
            model_name='autor',
            name='orcid',
            field=models.CharField(blank=True, help_text='Open Researcher and Contributor ID, vide http://www.orcid.org', max_length=19, null=True, validators=[django.core.validators.RegexValidator(code='orcid_invalid_format', message='Identyfikator ORCID to 4 grupy po 4 cyfry w każdej, oddzielone myślnikami', regex='^\\d\\d\\d\\d-\\d\\d\\d\\d-\\d\\d\\d\\d-\\d\\d\\d(\\d|X)$')], verbose_name='Identyfikator ORCID'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='bpp.Charakter_Formalny', verbose_name='Charakter nadrzędny'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='wchodzi_do_raportow',
            field=models.BooleanField(db_index=True, default=True, help_text='Jeżeli odznaczone, prace z jednostki nie sumują się w rankingu autorów.', verbose_name='Wchodzi do raportów'),
        ),
    ]



# -*- encoding: utf-8 -*-

from django.core.management import BaseCommand
from django.db import transaction

from bpp.models.wydawnictwo_ciagle import Wydawnictwo_Ciagle
from bpp.models.zrodlo import Punktacja_Zrodla


class Command(BaseCommand):
    help = "Ustawia punktacje dla niektorych typow prac"

    @transaction.atomic
    def handle(self, *args, **options):

        for praca in Wydawnictwo_Ciagle.objects.exclude(zrodlo=None).order_by("-rok"):
            try:
                punktacja = praca.zrodlo.punktacja_zrodla_set.get(rok=praca.rok)

                if (
                    punktacja.impact_factor != praca.impact_factor
                    or punktacja.punkty_kbn != praca.punkty_kbn
                ):
                    print(
                        f"Punkty pomiedzy praca {praca.tytul_oryginalny} a zrodlem {praca.zrodlo.nazwa} "
                        f"roznia sie {punktacja.impact_factor} != {praca.impact_factor} lub {punktacja.punkty_kbn} "
                        f"!= {praca.punkty_kbn}"
                    )
            except Punktacja_Zrodla.DoesNotExist:
                # Teoretycznie możnaby tą punktację wpisać...

                punkty_kbn = praca.punkty_kbn
                impact_factor = praca.impact_factor

                if punkty_kbn == 0 and impact_factor == 0:
                    continue

                # Sprawdźmy, czy inne wydawnictwa w tym źródle, w tym roku, mają taką samą punktację:
                inne = Wydawnictwo_Ciagle.objects.filter(
                    rok=praca.rok,
                    zrodlo=praca.zrodlo,
                ).exclude(pk=praca.pk)

                can_set = True

                if inne.exists:
                    for elem in inne:
                        if (
                            elem.impact_factor != 0
                            and elem.impact_factor != impact_factor
                        ) or (elem.punkty_kbn != 0 and elem.punkty_kbn != punkty_kbn):
                            print(
                                f"Dla roku {praca.rok} i pracy {praca.tytul_oryginalny}, inny rekord czyli "
                                f"{elem.tytul_oryginalny} punkty sie roznia {impact_factor} vs {elem.impact_factor}, "
                                f"{punkty_kbn} vs {elem.punkty_kbn}. "
                            )
                            can_set = False

                if can_set:
                    praca.zrodlo.punktacja_zrodla_set.create(
                        rok=praca.rok,
                        impact_factor=impact_factor,
                        punkty_kbn=punkty_kbn,
                    )
                    praca.save()
                    print(
                        f"Tworze punktacje zrodla {praca.zrodlo} dla roku {praca.rok} na bazie rekordu "
                        f"{praca.tytul_oryginalny}, PK={punkty_kbn}, impact_factor={impact_factor}"
                    )



import logging

from django import forms
from django.core.exceptions import ValidationError
from sentry_sdk import capture_exception

from crossref_bpp.models import CrossrefAPICache
from import_common.normalization import normalize_doi


class PobierzZCrossrefAPIForm(forms.Form):
    identyfikator_doi = forms.CharField(
        label="Identyfikator DOI",
        help_text="... może być również adres URL http://dx.doi.org/... lub http://doi.org/...",
        required=True,
        widget=forms.TextInput(attrs={"style": "width: 512px"}),
    )

    def clean_identyfikator_doi(self):
        v = self.cleaned_data["identyfikator_doi"]
        return normalize_doi(v)

    def clean(self):
        doi = self.cleaned_data["identyfikator_doi"]
        try:
            data = CrossrefAPICache.objects.get_by_doi(doi)
        except Exception as e:
            capture_exception(e)
            logging.exception(e)
            raise ValidationError(f"Podczas pobierania danych wystąpił błąd {e}")

        if data is None:
            raise ValidationError(
                f'Dla podanego DOI "{doi}" nie znaleziono nic po stronie CrossRef API'
            )

        self.cleaned_data["json_data"] = data



# Create your tests here.
from miniblog.models import Article


def test_Article___str__():
    a = Article(title="Artykuł", status="draft")
    assert (
        str(a) == 'Artykuł "Artykuł" - szkic' or str(a) == 'Artykuł "Artykuł" - draft'
    )

    a = Article(title="Artykuł", status="published")
    assert (
        str(a) == 'Artykuł "Artykuł" - opublikowany'
        or str(a) == 'Artykuł "Artykuł" - published'
    )



# Generated by Django 3.0.7 on 2020-08-03 18:11

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Notification",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("channel_name", models.CharField(db_index=True, max_length=128)),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("values", django.contrib.postgres.fields.jsonb.JSONField()),
            ],
        ),
    ]



from io import StringIO
from operator import neg
from typing import Iterable


class TeeIO(StringIO):
    def __init__(self, original, *args, **kw):
        super().__init__(*args, **kw)
        self.original = original

    def write(self, *args, **kw):
        try:
            self.original.write(*args, **kw)
        finally:
            return super().write(*args, **kw)

    def writelines(self, __lines: Iterable[str]) -> None:
        try:
            self.original.writelines(__lines)
        finally:
            return super().writelines(__lines)


def last_n_lines(s, nlines):
    if s is None:
        return
    lines = s.split("\n")
    prefix = ""
    if len(lines) > nlines:
        prefix = "[...]\n"
    return prefix + "\n".join(lines[neg(nlines) :])



# Generated by Django 2.1.7 on 2019-03-27 00:29

import django.contrib.postgres.fields.jsonb
import django.core.serializers.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('import_dyscyplin', '0015_auto_20190326_0553'),
    ]

    operations = [
        migrations.AlterField(
            model_name='import_dyscyplin_row',
            name='original',
            field=django.contrib.postgres.fields.jsonb.JSONField(encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
    ]



from datetime import timedelta

import pytest
from django.urls import reverse
from model_bakery import baker

from django.utils.timezone import localtime

from bpp.models import Wydawnictwo_Ciagle


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_detail(client, wydawnictwo_ciagle):
    res = client.get(
        reverse("api_v1:wydawnictwo_ciagle-detail", args=(wydawnictwo_ciagle.pk,))
    )
    assert res.status_code == 200


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_list(client, wydawnictwo_ciagle):
    res = client.get(reverse("api_v1:wydawnictwo_ciagle-list"))
    assert res.status_code == 200


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_filtering_1(api_client, wydawnictwo_ciagle):
    czas = localtime(wydawnictwo_ciagle.ostatnio_zmieniony).strftime(
        "%Y-%m-%d %H:%M:%S"
    )

    res = api_client.get(
        reverse("api_v1:wydawnictwo_ciagle-list") + f"?ostatnio_zmieniony_after={czas}"
    )
    assert res.json()["count"] == 1


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_filtering_2(api_client, wydawnictwo_ciagle):
    czas = localtime(
        wydawnictwo_ciagle.ostatnio_zmieniony + timedelta(seconds=1)
    ).strftime("%Y-%m-%d %H:%M:%S")

    res = api_client.get(
        reverse("api_v1:wydawnictwo_ciagle-list") + f"?ostatnio_zmieniony_after={czas}"
    )
    assert res.json()["count"] == 0


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_filtering_rok(api_client, wydawnictwo_ciagle, rok):
    res = api_client.get(
        reverse("api_v1:wydawnictwo_ciagle-list") + f"?rok_min={rok+1}"
    )
    assert res.json()["count"] == 0


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_ukryj_status(
    api_client, wydawnictwo_ciagle, uczelnia, przed_korekta, po_korekcie
):

    res = api_client.get(reverse("api_v1:wydawnictwo_ciagle-list"))
    assert res.json()["count"] == 1

    wydawnictwo_ciagle.status_korekty = przed_korekta
    wydawnictwo_ciagle.save()

    uczelnia.ukryj_status_korekty_set.create(status_korekty=przed_korekta)
    res = api_client.get(reverse("api_v1:wydawnictwo_ciagle-list"))
    assert res.json()["count"] == 0


@pytest.fixture
def wiele_wydawnictw_ciaglych(db):
    for a in range(100):
        baker.make(Wydawnictwo_Ciagle)


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_no_queries(
    wiele_wydawnictw_ciaglych, django_assert_max_num_queries, api_client
):
    with django_assert_max_num_queries(11):
        api_client.get(reverse("api_v1:wydawnictwo_ciagle-list"))


TEKST_STRESZCZENIA = b"Tekst streszczenia"
TEXT_OF_SUMMARY = b"Text of summary"


@pytest.fixture
def wydawnictwo_ciagle_ze_streszczeniami(wydawnictwo_ciagle, jezyki):
    wydawnictwo_ciagle.streszczenia.create(
        jezyk_streszczenia=jezyki["pol."], streszczenie=TEKST_STRESZCZENIA
    )

    wydawnictwo_ciagle.streszczenia.create(
        jezyk_streszczenia=jezyki["ang."], streszczenie=TEXT_OF_SUMMARY
    )

    return wydawnictwo_ciagle


@pytest.mark.django_db
def test_rest_api_wydawnictwo_ciagle_streszczenia_eksport(
    wydawnictwo_ciagle_ze_streszczeniami, client
):
    res = client.get(
        reverse(
            "api_v1:wydawnictwo_ciagle-detail",
            args=(wydawnictwo_ciagle_ze_streszczeniami.pk,),
        )
    )

    for elem in res.json()["streszczenia"]:
        ts = client.get(elem)
        assert (TEXT_OF_SUMMARY in ts.content) or (TEKST_STRESZCZENIA in ts.content)



# Generated by Django 3.2.15 on 2022-09-21 19:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0328_alter_uczelnia_wymagaj_informacji_o_oplatach"),
        ("bpp", "0329_auto_20220921_2030"),
    ]

    operations = []



from django.apps import AppConfig
from django.conf import settings
from django.db.models.signals import post_migrate


def create_entries(sender, **kw):

    from nowe_raporty.views import (
        AutorRaportFormView,
        JednostkaRaportFormView,
        WydzialRaportFormView,
    )

    for elem in [
        AutorRaportFormView,
        JednostkaRaportFormView,
        WydzialRaportFormView,
    ]:
        # Stwórz inicjalną wersję bazodanową formularza przy starcie aplikacji
        elem().get_initial()


class NoweRaportyConfig(AppConfig):
    name = "nowe_raporty"

    def ready(self):
        if getattr(settings, "TESTING"):
            return
        post_migrate.connect(create_entries, sender=self)



# Generated by Django 3.0.4 on 2020-05-24 22:34

from django.db import migrations, models

from bpp.models import CHARAKTER_OGOLNY_CHOICES


def guess_charakter_ogolny(apps, schema_editor):
    Charakter_Formalny = apps.get_model("bpp", "Charakter_Formalny")
    for elem in Charakter_Formalny.objects.all():
        if elem.charakter_ogolny == CHARAKTER_OGOLNY_CHOICES.inne:
            co = None

            if elem.charakter_pbn is not None:
                if elem.charakter_pbn.wlasciwy_dla == "article":
                    co = CHARAKTER_OGOLNY_CHOICES.artykul

                elif elem.charakter_pbn.wlasciwy_dla == "book":
                    co = CHARAKTER_OGOLNY_CHOICES.ksiazka

                elif elem.charakter_pbn.wlasciwy_dla == "chapter":
                    co = CHARAKTER_OGOLNY_CHOICES.rozdzial

            else:
                if elem.nazwa.lower().find("artyku") >= 0:
                    co = CHARAKTER_OGOLNY_CHOICES.artykul
                elif elem.nazwa.lower().find("książ") >= 0:
                    co = CHARAKTER_OGOLNY_CHOICES.ksiazka
                elif elem.nazwa.lower().find("rozdzia") >= 0:
                    co = CHARAKTER_OGOLNY_CHOICES.rozdzial

            if co is not None:
                elem.charakter_ogolny = co
                elem.save()
                continue


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0211_oznaczenie_wydania"),
    ]

    operations = [
        migrations.AddField(
            model_name="charakter_formalny",
            name="charakter_ogolny",
            field=models.CharField(
                choices=[("ksi", "Książka"), ("roz", "Rozdział"), ("xxx", "Inne")],
                default="xxx",
                help_text="Charakter ogólny uzywany jest m.in. do generowania opisów bibliograficznych. Stanowi on\n        ogólne określenie rekordu, czy jest to książka, rozdział czy coś innego. ",
                max_length=3,
            ),
        ),
        migrations.RunPython(guess_charakter_ogolny, migrations.RunPython.noop),
    ]



# Generated by Django 3.0.9 on 2020-10-10 22:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0226_rekord_mat_status"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="ukryj_status_korekty",
            options={
                "verbose_name": "ustawienie ukrywania statusu korekty",
                "verbose_name_plural": "ustawienia ukrywania statusów korekt",
            },
        ),
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="api",
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name="ukryj_status_korekty",
            name="multiwyszukiwarka",
            field=models.BooleanField(
                default=True,
                help_text="Nie dotyczy użytkownika zalogowanego. Użytkownik zalogowany widzi wszystkie prace w wyszukiwaniu. ",
            ),
        ),
    ]



from django.urls import reverse


def test_multiseek_status_korekty_ukrywanie(
    uczelnia,
    client,
    wydawnictwo_zwarte_przed_korekta,
    wydawnictwo_zwarte_po_korekcie,
    wydawnictwo_zwarte_w_trakcie_korekty,
    statusy_korekt,
    admin_client,
):
    res = client.get(reverse("multiseek:results"))
    assert b"Rezultaty wyszukiwania (3" in res.content

    for elem in ["przed korektą", "w trakcie korekty"]:
        uczelnia.ukryj_status_korekty_set.create(status_korekty=statusy_korekt[elem])

    res = client.get(reverse("multiseek:results"))
    assert b"Rezultaty wyszukiwania (1" in res.content

    res = admin_client.get(reverse("multiseek:results"))
    assert b"Rezultaty wyszukiwania (3" in res.content



from django.urls import reverse

from raport_slotow.views import ewaluacja

from bpp.models import Autor_Dyscyplina


def test_raport_ewaluacja_no_queries(
    rekord_slotu,
    django_assert_max_num_queries,
    admin_client,
    rok,
    autor_jan_kowalski,
    dyscyplina1,
):
    Autor_Dyscyplina.objects.create(
        rok=rok, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1
    )

    url = reverse(
        "raport_slotow:raport-ewaluacja",
    )

    r = ewaluacja.RaportSlotowEwaluacja()
    r.data = dict(od_roku=rok, do_roku=rok, _export="html")
    assert r.get_queryset().count() == 1

    with django_assert_max_num_queries(13):
        admin_client.get(
            url,
            data={
                "od_roku": 2017,
                "do_roku": 2021,
                "_export": "xlsx",
            },
        )



# Generated by Django 3.0.14 on 2021-08-17 19:01
from django.db import migrations

from django.contrib.postgres.operations import CreateExtension


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0286_auto_20210814_0104"),
    ]

    operations = [CreateExtension("pg_trgm")]



# Generated by Django 2.1.7 on 2019-07-07 18:29

import bpp.models.cache
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0166_auto_20190702_1200'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cache_punktacja_autora',
            name='rekord_id',
            field=bpp.models.cache.TupleField(base_field=models.IntegerField(), db_index=True, size=2),
        ),
        migrations.AlterField(
            model_name='cache_punktacja_dyscypliny',
            name='rekord_id',
            field=bpp.models.cache.TupleField(base_field=models.IntegerField(), db_index=True, size=2),
        ),
        migrations.AddField(
            model_name='cache_punktacja_autora',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cache_punktacja_dyscypliny',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.0.14 on 2021-08-08 23:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0024_auto_20210809_0125"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="scientist",
            options={
                "verbose_name": "Osoba w PBN API",
                "verbose_name_plural": "Osoby w PBN API",
            },
        ),
    ]



# Generated by Django 3.0.14 on 2021-09-05 20:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0032_sent_data_pbn_uid"),
    ]

    operations = [
        migrations.AddField(
            model_name="sentdata",
            name="typ_rekordu",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]



import pytest

from crossref_bpp.core import Komparator, StatusPorownania


def test_Komparator_porownaj_DOI_zadne():
    assert Komparator.porownaj_DOI(None).status == StatusPorownania.BLAD


@pytest.mark.django_db
def test_Komparator_porownaj_DOI_puste():
    assert Komparator.porownaj_DOI("nie ma takiego doi").status == StatusPorownania.BRAK


@pytest.mark.django_db
def test_Komparator_porownaj_DOI_obecne(wydawnictwo_ciagle):
    DOI = "10.500/foobar"
    wydawnictwo_ciagle.doi = DOI
    wydawnictwo_ciagle.save()

    assert (
        Komparator.porownaj_DOI("  10.500/FOOBAR").status == StatusPorownania.DOKLADNE
    )


@pytest.mark.django_db
def test_Komparator_porownaj_DOI_liczne(wydawnictwo_ciagle, wydawnictwo_zwarte):
    DOI = "10.500/foobar"

    for wydawnictwo in wydawnictwo_zwarte, wydawnictwo_ciagle:
        wydawnictwo.doi = DOI
        wydawnictwo_ciagle.save()

    assert (
        Komparator.porownaj_DOI("  10.500/FOOBAR").status == StatusPorownania.DOKLADNE
    )



# -*- coding: utf-8 -*-


from django.core.management import call_command
from django.db import migrations
from django.db.migrations.operations.special import RunPython

from bpp.migration_util import load_historic_fixture
from bpp.util import get_fixture


def load_fixtures(apps, schema_editor):
    Charakter_Formalny = apps.get_model("bpp", "Charakter_Formalny")
    for elem in get_fixture("charakter_formalny").values():
        Charakter_Formalny.objects.create(**elem)

    Funkcja_Autora = apps.get_model("bpp", "Funkcja_Autora")
    for elem in get_fixture("funkcja_autora").values():
        Funkcja_Autora.objects.create(**elem)

    Jezyk = apps.get_model("bpp", "Jezyk")
    for elem in get_fixture("jezyk").values():
        Jezyk.objects.create(**elem)

    for fixture in [
        "plec.json",
        "rodzaj_zrodla.json",
        "status_korekty.json",
        # 2017/02/06 przesuwam wczytywanie tego pliku do migracji 0067 - tabela Typ_KBN została zmieniona
        # (ma więcej kolumn), wczytywanie danych przez loaddata _zawiedzie_ ponieważ loaddata używa świeżych
        # obiektów, a nie obiektów na tym etapie migracji. Zatem, w migracji 0067 sprawdzamy, czy tabela
        # Typ_KBN jest pusta, jeżeli jest - to tam zostanie zaczytany typ_kbn.json
        #
        # A tak między nami, to na tym etapie, ta migracja uruchamiana jest wyłącznie podczas testowania bazy
        # danych czy tworzenia jej od zera. Na produkcyjnej bazie danych nie zostanie uruchomiona już nigdy.
        #
        # "typ_kbn.json",
        # "typ_odpowiedzialnosci.json",
        "tytul.json",
        # "um_lublin_uczelnia.json",
        # "um_lublin_wydzial.json",
        "zrodlo_informacji.json",
    ]:
        call_command("loaddata", fixture, app="bpp", verbosity=0)


def load_typ_odpowiedzialnosci(apps, schema_editor):
    return load_historic_fixture(apps, "typ_odpowiedzialnosci", "Typ_Odpowiedzialnosci")


class Migration(migrations.Migration):
    dependencies = [
        ("bpp", "0034_auto_20151011_1514"),
    ]

    operations = [RunPython(load_fixtures), RunPython(load_typ_odpowiedzialnosci)]



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0044_zaktualizuj_obce_archiwalne'),
    ]

    operations = [
        migrations.AlterField(
            model_name='jednostka',
            name='obca_jednostka',
            field=models.BooleanField(default=False, help_text=b'Zaznacz dla jednostki skupiaj\xc4\x85cej autor\xc3\xb3w nieindeksowanych,\n        np. dla "Obca jednostka" lub "Doktoranci".\n\n                <br/><br/>\n        Je\xc5\xbceli wi\xc4\x99cej, ni\xc5\xbc jedna jednostka w bazie danych ma to pole oznaczone jako \'PRAWDA\', autorzy\n        przypisywani b\xc4\x99d\xc4\x85 do jednostki obcej o ni\xc5\xbcszym numerze unikalnego identyfikatora (ID).\n        '),
        ),
    ]



# Generated by Django 3.0.14 on 2022-01-09 01:39

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0309_auto_20211110_0000"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0310_fix_refresh_cache_deadlocks")
        ),
    ]



from django.utils.translation import ngettext

from bpp.admin.helpers import sprobuj_wgrac_do_pbn
from bpp.models import Status_Korekty


def ustaw_status(queryset, nazwa_statusu):
    status = Status_Korekty.objects.get(nazwa=nazwa_statusu)
    return queryset.exclude(status_korekty=status).update(status_korekty=status)


def ustaw_przed_korekta(modeladmin, request, queryset):
    updated = ustaw_status(queryset, "przed korektą")
    modeladmin.message_user(
        request,
        f"Ustawiono status 'przed korektą' dla {updated} {ngettext('rekordu', 'rekordów', updated)}",
    )


ustaw_przed_korekta.short_description = "Ustaw status korekty: przed korektą"


def ustaw_po_korekcie(modeladmin, request, queryset):
    updated = ustaw_status(queryset, "po korekcie")
    modeladmin.message_user(
        request,
        f"Ustawiono status 'po korekcie' dla {updated} {ngettext('rekordu', 'rekordów', updated)}",
    )


ustaw_po_korekcie.short_description = "Ustaw status korekty: po korekcie"


def ustaw_w_trakcie_korekty(modeladmin, request, queryset):
    updated = ustaw_status(queryset, "w trakcie korekty")
    modeladmin.message_user(
        request,
        f"Ustawiono status 'w trakcie korekty' dla {updated} {ngettext('rekordu', 'rekordów', updated)}",
    )


ustaw_w_trakcie_korekty.short_description = "Ustaw status korekty: w trakcie korekty"


def wyslij_do_pbn(modeladmin, request, queryset):
    for elem in queryset:
        sprobuj_wgrac_do_pbn(request, elem)


wyslij_do_pbn.short_description = "Wyślij do PBN"



from django.db import models

from import_common.core import matchuj_publikacje
from import_common.normalization import normalize_isbn
from .base import BasePBNMongoDBModel

from django.utils.functional import cached_property

from bpp import const
from bpp.models.abstract import LinkDoPBNMixin

STATUS_ACTIVE = "ACTIVE"


class Publication(LinkDoPBNMixin, BasePBNMongoDBModel):
    url_do_pbn = const.LINK_PBN_DO_PUBLIKACJI
    atrybut_dla_url_do_pbn = "pk"

    class Meta:
        verbose_name = "Publikacja z PBN API"
        verbose_name_plural = "Publikacje z PBN API"
        unique_together = ["mongoId", "title", "isbn", "doi", "publicUri"]

    title = models.TextField(db_index=True, null=True, blank=True)
    doi = models.TextField(db_index=True, null=True, blank=True)
    publicUri = models.TextField(db_index=True, null=True, blank=True)
    isbn = models.TextField(db_index=True, null=True, blank=True)
    year = models.IntegerField(db_index=True, null=True, blank=True)

    # Nazwy pól wyciaganych "na wierzch" do pól obiektu
    # ze słownika JSONa (pole 'values')
    pull_up_on_save = ["title", "doi", "publicUri", "isbn", "year"]

    def type(self):
        return self.value("object", "type", return_none=True)

    def volume(self):
        return self.value("object", "volume", return_none=True)

    @cached_property
    def journal(self):
        return self.value_or_none("object", "journal")

    def pull_up_year(self):
        year = self.value_or_none("object", "year")
        if year is None:
            year = self.value_or_none("object", "book", "year")
        return year

    def pull_up_isbn(self):
        isbn = self.value_or_none("object", "isbn")
        if isbn is None:
            isbn = self.value_or_none("object", "book", "isbn")
        return normalize_isbn(isbn)

    def pull_up_publicUri(self):
        publicUri = self.value_or_none("object", "publicUri")
        if publicUri is None:
            publicUri = self.value_or_none("object", "book", "publicUri")
        return publicUri

    def policz_autorow(self):
        ret = 0

        for elem in self.autorzy:
            ret += len(self.autorzy[elem])
        return ret

    @cached_property
    def autorzy(self):
        ret = {}
        for elem in ["authors", "editors", "translators", "translationEditors"]:
            elem_dct = self.value_or_none("object", elem)
            if elem_dct:
                ret[elem] = elem_dct
        return ret

    @cached_property
    def journal_id(self):
        return self.value_or_none("object", "journal", "id")

    def matchuj_zrodlo_do_rekordu_bpp(self):
        if self.journal_id is not None:
            from bpp.models.zrodlo import Zrodlo

            return Zrodlo.objects.filter(pbn_uid_id=self.journal_id).first()

    def matchuj_do_rekordu_bpp(self):
        from bpp.models.cache import Rekord

        return matchuj_publikacje(
            Rekord,
            title=self.title,
            year=self.year,
            doi=self.doi,
            public_uri=self.publicUri,
            isbn=self.isbn,
            zrodlo=self.matchuj_zrodlo_do_rekordu_bpp(),
        )

    @cached_property
    def rekord_w_bpp(self):
        from bpp.models.cache import Rekord

        try:
            return Rekord.objects.get(pbn_uid_id=self.pk)
        except Rekord.MultipleObjectsReturned:
            return ";; ".join(
                [x.tytul_oryginalny for x in Rekord.objects.filter(pbn_uid_id=self.pk)]
            )
        except Rekord.DoesNotExist:
            pass

        return self.matchuj_do_rekordu_bpp()

    def __str__(self):
        ret = f"{self.title or self.value_or_none('object', 'title')}"
        if self.year:
            ret += f", {self.year}"
        if self.doi:
            ret += f", {self.doi}"
        return ret



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-08 19:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrator2', '0002_auto_20160124_1336'),
    ]

    operations = [
        migrations.AlterField(
            model_name='listaministerialnaintegration',
            name='file',
            field=models.FileField(upload_to='integrator2', verbose_name='Plik'),
        ),
        migrations.AlterField(
            model_name='listaministerialnaintegration',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Nazwa pliku'),
        ),
        migrations.AlterField(
            model_name='listaministerialnaintegration',
            name='status',
            field=models.IntegerField(choices=[(0, 'dodany'), (1, 'w trakcie analizy'), (2, 'przetworzony'), (3, 'przetworzony z błędami')], default=0),
        ),
    ]



# Generated by Django 3.0.14 on 2022-06-15 19:40

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0320_autor_aktualny_pole_znika"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0321_aktualna_jednostka_moze_byc_zadna"
            )
        )
    ]



from formdefaults import core

NO_TITLE_FORM = "Formularz domyślny"


class FormDefaultsMixin:
    def get_form_title(self):
        if hasattr(self, "title"):
            return self.title
        if hasattr(self, "label"):
            return self.label
        return NO_TITLE_FORM

    def get_initial(self):
        return core.get_form_defaults(self.form_class(), self.get_form_title())



# Generated by Django 3.2.15 on 2022-09-19 15:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0327_uczelnia_pokazuj_formularz_zglaszania_publikacji"),
    ]

    operations = [
        migrations.AlterField(
            model_name="uczelnia",
            name="wymagaj_informacji_o_oplatach",
            field=models.BooleanField(
                default=True,
                help_text="Gdy zaznaczone, moduł 'Zgłaszanie publikacji' będzie wyświetlać użytkownikowi formularz informacji o opłatach za publikację w przypadku zgłaszania artykułu lub monografii. Gdy odznaczone, taki formularz nie bedzie wyświetlany, niezależnie od rodzaju zgłaszanej publikacji. ",
                verbose_name="Wymagaj informacji o opłatach",
            ),
        ),
    ]



import pytest

from import_common.exceptions import BadNoOfSheetsException, ImproperFileException
from import_dyscyplin.core import przeanalizuj_plik_xls
from import_dyscyplin.models import Import_Dyscyplin_Row


def test_przeanalizuj_plik_xls_zly_plik(conftest_py):
    with pytest.raises(ImproperFileException):
        przeanalizuj_plik_xls(conftest_py, parent=None)


def test_przeanalizuj_plik_xls_wiele_skoroszytow(test3_multiple_sheets_xlsx):
    with pytest.raises(BadNoOfSheetsException):
        przeanalizuj_plik_xls(test3_multiple_sheets_xlsx, parent=None)


def test_przeanalizuj_plik_xls_dobry(test1_xlsx, import_dyscyplin):
    import_dyscyplin.plik.save("test.xlsx", open(test1_xlsx, "rb"))
    import_dyscyplin.stworz_kolumny()

    przeanalizuj_plik_xls(test1_xlsx, parent=import_dyscyplin)
    assert Import_Dyscyplin_Row.objects.count() == 6



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-19 09:40
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0106_pokazuj_uczelnia'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("107_bpp_rekord")
        ),

        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("107_bpp_autorzy")
        ),

        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("107_cache_functions")
        ),
    ]



# Generated by Django 3.0.11 on 2021-03-12 11:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0246_auto_20210312_1228"),
    ]

    operations = [
        migrations.AddField(
            model_name="funkcja_autora",
            name="pokazuj_za_nazwiskiem",
            field=models.BooleanField(
                default=False,
                help_text="Zaznaczenie tego pola sprawi, że ta funkcja\n        "
                "będzie wyświetlana na stronie autora, za nazwiskiem.",
            ),
        ),
    ]



# Generated by Django 3.0.14 on 2022-05-03 21:51

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0318_jedno_podstawowe_miejsce_pracy"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0319_aktualna_jednostka_to_podstawowe_miejsce"
            )
        )
    ]



# Generated by Django 3.0.14 on 2021-11-22 00:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ewaluacja2021", "0008_auto_20211122_0103"),
    ]

    operations = [
        migrations.AddField(
            model_name="zamowienienaraport",
            name="status",
            field=models.CharField(blank=True, default="", max_length=255, null=True),
        ),
    ]



from rest_framework import serializers

from bpp.models import Jednostka, Wydzial, Uczelnia


class UczelniaSerializer(serializers.ModelSerializer):
    obca_jednostka = serializers.HyperlinkedRelatedField(
        view_name="api_v1:jednostka-detail", read_only=True
    )

    class Meta:
        model = Uczelnia
        fields = [
            "id",
            "nazwa",
            "skrot",
            "pbn_id",
            "slug",
            "obca_jednostka",
        ]


class WydzialSerializer(serializers.ModelSerializer):
    uczelnia = serializers.HyperlinkedRelatedField(
        view_name="api_v1:uczelnia-detail", read_only=True
    )

    class Meta:
        model = Wydzial
        fields = [
            "id",
            "uczelnia",
            "nazwa",
            "skrot_nazwy",
            "skrot",
            "opis",
            "slug",
            "poprzednie_nazwy",
            "widoczny",
            "kolejnosc",
            "otwarcie",
            "zamkniecie",
            "ostatnio_zmieniony",
        ]


class JednostkaSerializer(serializers.ModelSerializer):
    wydzial = serializers.HyperlinkedRelatedField(
        view_name="api_v1:wydzial-detail", read_only=True
    )
    uczelnia = serializers.HyperlinkedRelatedField(
        view_name="api_v1:uczelnia-detail", read_only=True
    )

    class Meta:
        model = Jednostka
        fields = [
            "id",
            "nazwa",
            "skrot",
            "aktualna",
            "opis",
            "slug",
            "widoczna",
            "wchodzi_do_raportow",
            "skupia_pracownikow",
            "wydzial",
            "uczelnia",
            "ostatnio_zmieniony",
        ]



# Generated by Django 3.2.15 on 2022-09-21 18:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0327_uczelnia_pokazuj_formularz_zglaszania_publikacji"),
    ]

    operations = [
        migrations.AddField(
            model_name="charakter_formalny",
            name="charakter_crossref",
            field=models.PositiveSmallIntegerField(
                blank=True,
                choices=[("1", "journal-article"), ("2", "proceedings-article")],
                default=None,
                null=True,
                unique=True,
                verbose_name="Charakter w CrossRef",
            ),
        ),
    ]



# -*- encoding: utf-8 -*-

from django.core.management import BaseCommand
from django.db import transaction

from bpp.models import (
    Praca_Doktorska,
    Praca_Habilitacyjna,
    Patent,
    parse_informacje_as_dict,
    wez_zakres_stron,
)
from bpp.models.abstract import strony_regex, BRAK_PAGINACJI
from bpp.models.wydawnictwo_ciagle import Wydawnictwo_Ciagle
from bpp.models.wydawnictwo_zwarte import Wydawnictwo_Zwarte
from django_bpp.sitemaps import Praca_HabilitacyjnaSitemap


class Command(BaseCommand):
    help = "Ustawia parametry strony, tom, nr zeszytu dla prac >= 2010 roku, jeżeli nie ustawione"

    def add_arguments(self, parser):
        parser.add_argument("--dry-run", action="store_true")

    def ustaw_atrybut(self, obiekt, atrybut, wartosc):
        if wartosc is None:
            return

        obecny = getattr(obiekt, atrybut)
        if obecny is None or obecny == "":
            print(
                f"+{obiekt.pk}: {obiekt.tytul_oryginalny}: {atrybut} ustawione na {wartosc}"
            )
            setattr(obiekt, atrybut, wartosc)
            return True
        else:
            if obecny != wartosc:
                print(
                    f"-{obiekt.pk}: {obiekt.tytul_oryginalny}: {atrybut} obecny: {obecny}, "
                    f"ze szczegolow {wartosc}, nie zmieniam"
                )

    @transaction.atomic
    def handle(self, dry_run, *args, **options):
        for klass in (
            Wydawnictwo_Ciagle,
            Wydawnictwo_Zwarte,
            Praca_Doktorska,
            Praca_Habilitacyjna,
            Patent,
        ):
            q = (
                klass.objects.exclude(szczegoly="")
                .exclude(szczegoly=None)
                .exclude(rok__lt=2010)
            )

            for rekord in q:
                res = parse_informacje_as_dict(rekord.informacje)

                save = False

                if self.ustaw_atrybut(rekord, "tom", res.get("tom")):
                    save = True

                if klass not in [Wydawnictwo_Zwarte]:
                    if self.ustaw_atrybut(rekord, "nr_zeszytu", res.get("numer")):
                        save = True

                strony = wez_zakres_stron(rekord.szczegoly)
                pole = "szczegoly"

                if strony:
                    if rekord.strony is not None and rekord.strony != "":
                        if rekord.strony != strony:
                            print(
                                f"-{rekord.pk}: {rekord.tytul_oryginalny} strony obecnie to {rekord.strony}, "
                                f"wartosc z pola {pole} to {strony} ({getattr(rekord,pole)}), nie zmieniam"
                            )
                    else:
                        print(
                            f"+{rekord.pk}: {rekord.tytul_oryginalny}: strony ustawione na {strony} "
                            f"na podstawie pola {pole} ({getattr(rekord, pole)})"
                        )

                        rekord.strony = strony
                        save = True

                if save and not dry_run:
                    rekord.save()



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0069_eksport_pbn_charaktery'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patent',
            name='informacje',
            field=models.TextField(db_index=True, null=True, verbose_name=b'Informacje', blank=True),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='informacje',
            field=models.TextField(db_index=True, null=True, verbose_name=b'Informacje', blank=True),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='informacje',
            field=models.TextField(db_index=True, null=True, verbose_name=b'Informacje', blank=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='informacje',
            field=models.TextField(db_index=True, null=True, verbose_name=b'Informacje', blank=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='informacje',
            field=models.TextField(db_index=True, null=True, verbose_name=b'Informacje', blank=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='wydawnictwo_nadrzedne',
            field=models.ForeignKey(on_delete=models.CASCADE, related_name='wydawnictwa_powiazane_set', blank=True, to='bpp.Wydawnictwo_Zwarte', help_text=b'Je\xc5\xbceli dodajesz rozdzia\xc5\x82,\n        tu wybierz prac\xc4\x99, w ramach kt\xc3\xb3rej dany rozdzia\xc5\x82 wyst\xc4\x99puje.', null=True),
        ),
    ]



# Generated by Django 3.0.4 on 2020-05-17 22:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("import_dbf", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bib",
            name="idt2",
            field=models.ForeignKey(
                blank=True,
                db_column="idt2",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="import_dbf.Bib",
            ),
        ),
    ]



# Generated by Django 3.0.11 on 2021-02-28 12:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("taggit", "0003_taggeditem_add_unique_index"),
        ("bpp", "0237_auto_20210223_2228"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="autor",
            name="pesel_md5",
        ),
    ]



import sys
import traceback
from datetime import datetime, timedelta

from dbtemplates.admin import TemplateAdmin, TemplateAdminForm
from dbtemplates.models import Template
from dbtemplates.utils.cache import remove_cached_template
from dbtemplates.utils.template import check_template_syntax
from django.conf.urls import url
from django.core.exceptions import ValidationError
from django.template import Context, TemplateSyntaxError
from django.template.engine import Engine
from django.template.loaders.cached import Loader as CachedLoader
from django.template.response import TemplateResponse

from django.contrib import admin, messages

from bpp.util import rebuild_instances_of_models

admin.site.unregister(Template)

ILE_OSTATNICH_PRAC = 25


class BppTemplateAdminForm(TemplateAdminForm):
    def clean_content(self):
        content = self.cleaned_data.get("content", "")

        class FakeTemplate:
            content = None

        FakeTemplate.content = content

        if not content:
            raise ValidationError(
                "Szablon nie może być pusty. Użyj np kodu {#...#} zamiast. "
            )

        valid, error = check_template_syntax(FakeTemplate)
        if not valid:
            raise ValidationError(
                f"Błąd przy próbie analizy szablonu: Proszę o korektę przed zapisaniem. Przyczyna błędu: {error}"
            )

        return content


@admin.register(Template)
class BppTemplateAdmin(TemplateAdmin):
    form = BppTemplateAdminForm

    def template_updated(self, request, obj):
        """Zresetuj cache zarówno dbtemplates, jak i CachedLoader'a"""

        remove_cached_template(obj)

        loaders = Engine.get_default().template_loaders
        for loader in loaders:
            if isinstance(loader, CachedLoader):
                key_name = loader.cache_key(obj.name)
                if key_name in loader.get_template_cache:
                    del loader.get_template_cache[key_name]
                # Jeszcze jest opcja uruchomic cl.reset(), ale na tym etapie
                # chyba nei ma takiej potrzeby.

        # Zlokalizuj wszystkie modele, korzystające z tej templatki:
        from bpp.models.szablondlaopisubibliograficznego import (
            SzablonDlaOpisuBibliograficznego,
        )

        modele = SzablonDlaOpisuBibliograficznego.objects.get_models_for_template(obj)

        if not modele:
            messages.info(
                request,
                "Żaden z modeli rekordów publikacji nie korzysta z tego szablonu, "
                "więc żaden nie będzie przebudowany",
            )
            return

        ILE_DNI = 7
        dni_temu = datetime.now() - timedelta(days=ILE_DNI)

        messages.info(
            request,
            f"Włączono przebudowę modeli - w sumie dla {len(modele)} rodzajów. Przebudowa obejmie rekordy "
            f"ostatnio zmodyfikowane w ciągu ostatnich {ILE_DNI} dni. Zmiany powinny być zauważalne "
            "po dłuższej chwili. Pozostałe rekordy zostaną przebudowane w godzinach nocnych. ",
        )
        rebuild_instances_of_models(modele, ostatnio_zmieniony__gte=dni_temu)

    def save_model(self, request, obj, form, change):
        pk = obj.pk

        super(TemplateAdmin, self).save_model(request, obj, form, change)

        if pk is not None:
            # Nie aktualizuj cache przy dodawaniu nowych rekordów.
            self.template_updated(request, obj)

    def delete_model(self, request, obj):
        super(TemplateAdmin, self).delete_model(request, obj)
        self.invalidate_cache(request, Template.objects.filter(pk=obj.pk))
        self.template_updated(request, obj)

    def get_urls(self):
        urls = super().get_urls()

        preview_urls = [
            url(
                r"^preview/$",
                self.admin_site.admin_view(self.opis_bibliograficzny_preview),
            )
            # Add here more urls if you want following same logic
        ]

        return preview_urls + urls

    # Your view definition fn
    def opis_bibliograficzny_preview(self, request):
        template = request.GET.get("template")

        from django.template import Template as DjangoTemplate

        template_okay = True
        exception = None
        lista_prac = []
        tb = None

        try:
            django_template = DjangoTemplate(template)
        except TemplateSyntaxError as e:
            template_okay = False
            exception = e
            type, value, tb = sys.exc_info()

        if template_okay:
            from bpp.models.cache import Rekord

            ostatnie_prace = Rekord.objects.all().order_by("-ostatnio_zmieniony")[
                :ILE_OSTATNICH_PRAC
            ]

            for elem in ostatnie_prace:
                context = Context({"praca": elem.original})
                lista_prac.append(django_template.render(context))

            #
        context = dict(
            self.admin_site.each_context(request),
            template=template,
            lista_prac=lista_prac,
            template_okay=template_okay,
            exception=exception,
            ile_ostatnich_prac=ILE_OSTATNICH_PRAC,
            is_popup=True,
            traceback="\n".join(traceback.format_tb(tb)),
            tytul="Szybki podgląd szablonu",
        )

        return TemplateResponse(
            request, "admin/opis_bibliograficzny_preview.html", context
        )



import logging
import os
from decimal import Decimal
from operator import attrgetter

import simplejson

from ..models import LiczbaNDlaUczelni
from .sumator_base import SumatorBase
from .util import (
    encode_datetime,
    get_lista_autorow_na_rekord,
    get_lista_prac,
    lista_prac_na_tuples,
    maks_pkt_aut_calosc_get_from_db,
    maks_pkt_aut_monografie_get_from_db,
)

logger = logging.getLogger(__name__)


class Ewaluacja3NBase(SumatorBase):
    def __init__(self, nazwa_dyscypliny="nauki medyczne", output_path=None):
        """
        maks_pkt_aut_calosc
            maksymalna ilość punktów dla poszczególnych autorów, słownik autor->maks pkt

        maks_pkt_aut_monografie
            maksymalna ilość punktów dla autorów za monografie, słownik autor->maks pkt

        """

        self.nazwa_dyscypliny = nazwa_dyscypliny
        self.output_path = output_path

        maks_pkt_aut_calosc = maks_pkt_aut_calosc_get_from_db(self.nazwa_dyscypliny)

        maks_pkt_aut_monografie = maks_pkt_aut_monografie_get_from_db(
            self.nazwa_dyscypliny
        )

        self.liczba_n = LiczbaNDlaUczelni.objects.get(
            dyscyplina_naukowa__nazwa=self.nazwa_dyscypliny
        ).liczba_n

        SumatorBase.__init__(
            self=self,
            liczba_2_2_n=Decimal("2.2") * self.liczba_n,
            liczba_0_8_n=Decimal("0.8") * self.liczba_n,
            maks_pkt_aut_calosc=maks_pkt_aut_calosc,
            maks_pkt_aut_monografie=maks_pkt_aut_monografie,
        )

    def get_data(self):
        logger.info("get_data start")
        self.autorzy_na_rekord = get_lista_autorow_na_rekord(self.nazwa_dyscypliny)

        self.id_wszystkich_autorow = set()
        for elem in self.autorzy_na_rekord.values():
            for x in elem:
                self.id_wszystkich_autorow.add(x)

        self.lista_prac_db = get_lista_prac(self.nazwa_dyscypliny)
        self.lista_prac_tuples = lista_prac_na_tuples(
            self.lista_prac_db, self.autorzy_na_rekord
        )
        logger.info("get_data finished")

    def powitanie(self):
        print(
            f"Szukam dla: {self.nazwa_dyscypliny}, liczba N: {self.liczba_n}, 2.2*N: {self.liczba_2_2_n}, "
            f"0.8*N: {self.liczba_0_8_n}"
        )

    def pozegnanie(self):
        print(
            f"Obecna maks pkd: {self.suma_pkd}, suma slotow: {self.sumy_slotow}, ilosc prac: {len(self.id_rekordow)}"
        )

    def zrzuc_dane(self, nazwa):
        output = {
            "ostatnia_zmiana": getattr(
                max(self.lista_prac, key=attrgetter("ostatnio_zmieniony")),
                "ostatnio_zmieniony",
                "brak rekordów",
            ),
            "dyscyplina": self.nazwa_dyscypliny,
            "liczba_n": self.liczba_n,
            "liczba_0_8_n": self.liczba_0_8_n,
            "liczba_2_2_n": self.liczba_2_2_n,
            "sumy_slotow": self.sumy_slotow,
            "maks_pkt_aut_calosc": self.maks_pkt_aut_calosc,
            "maks_pkt_aut_monografie": self.maks_pkt_aut_monografie,
            "wejscie": [x for x in self.lista_prac],
            "optimum": [x for x in self.id_rekordow],
        }

        nazwa = nazwa + "_" + self.nazwa_dyscypliny.replace(" ", "_") + ".json"

        if self.output_path is not None:
            nazwa = os.path.abspath(os.path.join(self.output_path, nazwa))

        with open(nazwa, "w") as f:
            simplejson.dump(
                output,
                f,
                indent=4,
                use_decimal=True,
                namedtuple_as_object=True,
                tuple_as_array=True,
                default=encode_datetime,
            )

        print(f"Dane zrzucone do {nazwa}")



# Generated by Django 2.2.10 on 2020-02-29 22:53

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0198_auto_20200229_1644"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0199_alias_wydawcy_trigger")
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-30 16:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0131_liczba_cytowan'),
    ]

    operations = [
        migrations.RunSQL(
            "ALTER TABLE bpp_wydawnictwo_ciagle_autor ADD CONSTRAINT bpp_wydawnictwo_ciagle_autor_unique_rekord_id_kolejnosc "
            "UNIQUE (rekord_id, kolejnosc) DEFERRABLE INITIALLY DEFERRED ;",

            "ALTER TABLE bpp_wydawnictwo_ciagle_autor DROP CONSTRAINT bpp_wydawnictwo_ciagle_autor_unique_rekord_id_kolejnosc "
        ),

        migrations.RunSQL(
            "ALTER TABLE bpp_wydawnictwo_zwarte_autor ADD CONSTRAINT bpp_wydawnictwo_zwarte_autor_unique_rekord_id_kolejnosc "
            "UNIQUE (rekord_id, kolejnosc) DEFERRABLE INITIALLY DEFERRED ;",

            "ALTER TABLE bpp_wydawnictwo_zwarte_autor DROP CONSTRAINT bpp_wydawnictwo_zwarte_autor_unique_rekord_id_kolejnosc "
        ),

        migrations.RunSQL(
            "ALTER TABLE bpp_patent_autor ADD CONSTRAINT bpp_patent_autor_unique_rekord_id_kolejnosc "
            "UNIQUE (rekord_id, kolejnosc) DEFERRABLE INITIALLY DEFERRED ;",

            "ALTER TABLE bpp_patent_autor DROP CONSTRAINT bpp_patent_autor_unique_rekord_id_kolejnosc "
        ),

    ]
